 
# Define master function that is called for each degree change in each climate model and 11 year period. 
# In each case, the function looks up the mean temperature data, calculates a lagged (5 day moving average)
# mean temperature, joins with the cluster fits, projects the mortality and calculated relative risk.

dT_func <- function (gcm_sel ="baseline" ,
                     dT_c_sel = 0,
                     rcp_sel = "baseline"  ,
                     dt_yr_sel = 2003,  
                     cluster_fits  = cluster_fits_doy,
                     fit_cp = c("cp_out3", "cp_out4"),
                     cira_folder = "/media/jdrive/projects/COOLIT13_RiskComm/Mortality/Output/Trim/" 
) {
  print (gcm_sel) ; print (dT_c_sel) ; print(rcp_sel); print(dt_yr_sel)
  # get data
  
  if(gcm_sel == "baseline") {
    tic(msg = "get_tmean_livneh")
    years_livneh =  1993:2013 
    ym <- expand.grid(year = years_livneh,  month = sprintf("%02d", seq(1:12)))
    tmean_daily <- map2_dfr(.x = ym$year, .y = ym$month, .f = get_tmean_livneh, cities = "all")%>% 
      unnest() %>% ungroup() %>% 
      group_by(city, CITYNAME, year,   gcm  , rcp, dt_yr ) %>% 
      nest(.key = "doy_tmean0")  %>% 
      mutate(dt_yr = dt_yr_sel)
    toc()
  } else {
    tic(msg = "get_tmean")
    tmean_daily <- get_tmean (cira_folder = cira_folder,
                              gcm = gcm_sel , rcp =  rcp_sel ,  dt_yr =  dt_yr_sel  )
    toc()
  }
  
  # Lag calc   
  tic(msg = "calculate lagged tmean")
  tmean_daily <- tmean_daily %>% 
    mutate(dT_c = dT_c_sel ,
           doy_tmean0 = map( doy_tmean0, lag_calc )) %>% 
    rename (doy_tmean = doy_tmean0)
  toc()
  
  #join to cluster fits, apply bounds, and other calculations
  tic(msg = "join_doy_proj")
  tmean_daily <- join_doy_proj_avg (tmean_daily = tmean_daily , cluster_param = cluster_fits_doy) 
  toc()
  
  
  ## add projected mortality and RR to tmean_daily  (trouble with list position means this may be more complicated than needed)
  print(fit_cp) 


if (all(fit_cp == c("cp_out3", "cp_out4"))){   
  print("day_tm")
    tic(msg = "day_tm operation cp 3 cp 4")
    tmean_daily <- tmean_daily %>%  
      mutate( 
               day_tm_av = pmap(list(day_tm,  cp_out3  , cp_out4  ) ,
                                ~project_spline_rr_av( ..1, list(..2, ..3)))
      )
    toc() 
}  
  
if (all(fit_cp == c( "cp_out4"))){   
    print("day_tm")
    tic(msg = "day_tm operation cp 4")
    tmean_daily <- tmean_daily %>%  
      mutate( 
        day_tm_4 = pmap(list(day_tm,   cp_out4  ),
                        ~project_spline_rr_av( ..1, list(..2 )))
      )
    toc() 
  }  
  
  

if (all(fit_cp == c("cp_out1"))){   
    print("day_tm")
    tic(msg = "day_tm operation cp 1")
    tmean_daily <- tmean_daily %>%  
      mutate(  day_tm_1 = pmap(list(day_tm,   cp_out1  ),
                               ~project_spline_rr_av( ..1, list(..2 ))) 
      )
    toc() 
  }  

  if (all(fit_cp == c("cp_out2"))){   
    print("day_tm")
    tic(msg = "day_tm operation cp 2")
    tmean_daily <- tmean_daily %>%  
      mutate(  day_tm_2 = pmap(list(day_tm,   cp_out2  ),
                               ~project_spline_rr_av( ..1, list(..2 ))) 
      )
    toc() 
  }    
  return(tmean_daily)
}
 
