### Create date: 2019-10-29 
### Adapted from previous notebook code in CIRA_Mortality .rmd files.
### Author: Claire Lay
#### Create a function ('cluster_load)
#This finds the cluster results, and saves to a nested tibble for further use.
#
#cluster_load uses load_parms and pluck_all


load_parms <- function(RData, env = new.env()){
  # loads anay .Rdata into new env, and removes explit year identifiers for Vodonos output ("years4") from object names, before returning objects as list
  load(RData, env) # 
  
  list_parms = mget(ls(env), env)
  new_names <- gsub("_years([0-9])","", names(list_parms))# generalize object names so not hindered with year labels
  new_names <- gsub("_y([0-9])","", new_names)# generalize object names so not hindered with year labels
  new_names <- gsub("cp_15","cp_05", new_names)#for cases with non-standard names
  list_parms<- setNames(list_parms, new_names) 
} 


pluck_all = function(x , col="cp_0", ns = nsim ){
  require(purrr)
  coeff <- pluck(x, col, "coefficients")
  varcov <- pluck(x, col, "vcov" ) 
  if(col == "cp_0"){knot = "knots_1"}else{knot ="knots_2"}
  
  list (  
    bound = c(range(pluck(x, col,  "predvar"))),
    knots = c(pluck(x,  knot)),
    coeff = c(coeff),
    varcov = (varcov),
    coeff_sim = (mvrnorm(ns, 
                         coeff,
                         varcov))
  )  }   


cluster_load <- function (c_cluster = 6, 
                          nsim = 1000, 
                          out_folder = "output/vodonos_out/2019-06-13_mvcl_4_time",
                          time_periods = c(3, 4))  {
  #Function w/o loading of meta-regression for adaptation parameters (ie.ac) 
  #Load the contents of the saved Rdata crosspred(cp) objects for a cluster from original Vodonos output--for cross-pred (cp) objects, mvmeta was only used to select the best knot positons across cities in clusters
  #'cluster_load' function pulls in all model objects for cluster for the a time period, but only keeps the coefficients, vcov, boundaries, and knots.
  #It organizes these into two list columns (for daily and moving average arguments).
  #
  require(here); require(dplyr); require(tidyr); require(purrr); require(MASS)

  print (c_cluster) 
  
  cluster_f <- tibble(cluster = c_cluster , 
                      time_period = time_periods, 
                      cp_fname =  here::here(out_folder,
                                             gsub("X", c_cluster, 
                                                  paste0("mv_clX/mv_clX/cp.clusterX.years", time_period, ".Rdata"))),
                      cp_out =   map (cp_fname, .f = load_parms)   ,  
                      mv_fname =  here::here(out_folder,
                                             gsub("X", c_cluster,
                                                  paste0("mv_clX/mv_clX/mv_clX_y", time_period, ".Rdata"))) ,
                      mv_out =  map (mv_fname, .f = load_parms)  ,
                      daily_arg = map (cp_out, ~pluck_all(., col="cp_0", ns = nsim ) ),
                      ma15_arg = map (cp_out, ~pluck_all(., col="cp_05", ns = nsim ) ) )  #%>% 
    #select(-cp_fname, -cp_out)
  
}


cluster_load_cp <- function (c_cluster = 1,  
                          out_folder = "output/vodonos_out/2019-06-13_mvcl_4_time/",
                          time_period = 4) {
  #Load the contents of the saved Rdata crosspred(cp) objects for a cluster from original Vodonos output--for cross-pred (cp) objects, mvmeta was only used to select the best knot positons across cities in clusters
  #'cluster_load' function pulls in all model objects for cluster for the a time period, but only keeps the coefficients, vcov, boundaries, and knots.
  #It organizes these into two list columns (for daily and moving average arguments).
  require(here)
  
  cp_fname <- gsub("Z", time_period, 
                   gsub("X", c_cluster,
                        "/mv_clX/mv_clX/cp.clusterX.yearsZ.Rdata"))
  cp_fname <- here::here(out_folder, cp_fname)
  load(cp_fname) 
  
  if (exists("cp_15_years4")) {cp_05_years4  <-  cp_15_years4}# corrects a naming issue in some vodonos output
 
  eval(parse(text =paste0("cp_0_obj <- cp_0_years", time_period))) # rename year-specific cross-pred object to general
  eval(parse(text =paste0("cp_05_obj <- cp_05_years", time_period))) # rename year-specific cross-pred  object to general
  
  daily_tmax0_arg = list ( c(  
    bound =  list (c(range (cp_0_obj$predvar)  )),
    knots = list (c(knots_1)),
    coeff = list (c(cp_0_obj$coefficients)),
    varcov = list (cp_0_obj$vcov)  ,
    coeff_sim = list(mvrnorm(nsim, cp_0_obj$coefficients, 
                             cp_0_obj$vcov ))) )
  
  ma15_tmax05_arg =list ( c( 
    bound =  list (c(range (cp_05_obj$predvar)  )),
    knots = list (c(knots_2)),
    coeff = list (c(cp_05_obj$coefficients)),
    varcov = list (cp_05_obj$vcov )   ,
    coeff_sim = list(mvrnorm(nsim, 
                             cp_05_obj$coefficients, 
                             cp_05_obj$vcov ))) )
  # change to tibble for purrr operations later
  cluster_0_fits <- tibble (cluster = c_cluster,  
                            time_period = time_period,
                            daily_tmax0_arg = daily_tmax0_arg  )
  
  cluster_05_fits <- tibble (cluster = c_cluster,
                             ma15_tmax05_arg = ma15_tmax05_arg  )
  
  cluster_x_fits <- cluster_0_fits %>%  
    inner_join(cluster_05_fits)
  
}

 
cluster_load_mv <- function (c_cluster = 1,  
                             out_folder = "output/vodonos_out/2019-06-13_mvcl_4_time/",
                             time_period = 4){
  # Loads the meta-smoothed coefficients and variance-covariance matrices from Vodonos-Zilberg .Rdata output 
  # fitted by cluster in the second stage of the temperature exposure-response-function (ERF) characterization for bot. 
  # Loops over clusters and fitted historical time-periods.
  
  mv_fname <- gsub("Z", time_period,
                   gsub("X", c_cluster,
                        "/mv_clX/mv_clX/mv_clX_yZ.Rdata"))
  mv_fname <- here::here(out_folder, mv_fname)
  load(mv_fname)

  slist_ylist <- list(cluster = c_cluster,
                      time_period = time_period, 
                      Slist_t0 = Slist_1, 
                      ymat_t0 = ymat_1, 
                      Slist_t05 = Slist_2, 
                      ymat_t05 = ymat_2)
}
  


cluster_arg_meta <- function (c_cluster = 1, 
                              out_folder_sr = "output/vodonos_out/2019-06-13_mvcl_4_time/", #simple fit
                              out_folder_mr = "output/vodonos_out/2019-09-02_Temperature-and-Mortality/Meta-regression", #fit with added predictors
                              time_period = 4) {
  # Loads first, the crosspred output as in cluster_load_cp(), then the meta-smoothed ERF coefficients 
  # as in cluster_load_mv(), then the meta-regression .Rdata objects from Vodonos-Zilberg outputs of the 
  # meta-regression to relate the ERF coefficient values to city-specific predictor values such as air 
  # conditioning and population features. These meta-regressions were fitted with both seasonal mean 
  # temperatures and without for most clusters, and the function loads both meta-regression outputs. 
  # Produces list columns for each lag term containing the original meta-smoothed ERF, the boundary and 
  # interior knots, the original meta-smoothed variance-covariance matrix
  
  require(here)
  print (c_cluster)
  cp_fname <- gsub("Z", time_period, 
                   gsub("X", c_cluster,
                        "/mv_clX/mv_clX/cp.clusterX.yearsZ.Rdata"))
  cp_fname <- here::here(out_folder_sr, cp_fname)
  load(cp_fname) 
  
  if (exists("cp_15_years4")) {cp_05_years4  <-  cp_15_years4}# corrects a naming issue in some vodonos output
  
  eval(parse(text =paste0("cp_0_obj <- cp_0_years", time_period))) # rename year-specific cross-pred object to general
  eval(parse(text =paste0("cp_05_obj <- cp_05_years", time_period))) # rename year-specific cross-pred  object to general
  
  folder_season_mean <-   gsub("X", c_cluster,"ClusterX/cl_specific_seas_mean/" )
  folder_no_season <-   gsub("X", c_cluster,"ClusterX/cl_specific_no_seas_mean")
  
  # get meta regression files for added predictor fits including seasonal mean and no seasonal mean fits.
  mr_files_sm <- list.files(here::here(out_folder_mr, folder_season_mean), full.names = TRUE)
  mr_t0_sm_fname  <- mr_files_sm [grepl("lag0.Rdata", mr_files_sm)]
  mr_t05_sm_fname <- mr_files_sm [grepl("lag05.Rdata", mr_files_sm)]
  
  mr_files_nsm <- list.files(here::here(out_folder_mr, folder_no_season), full.names = TRUE)
  mr_t0_nsm_fname  <- mr_files_nsm [grepl("lag0.Rdata", mr_files_nsm)]
  mr_t05_nsm_fname <- mr_files_nsm [grepl("lag05.Rdata", mr_files_nsm)]
  
  # Load the daily and 5-day lagged mvmeta fitted models.  'get(load(filename))' loads the fittedm model object to an object with a standardized name
  mr_t0_sm <- get(load(mr_t0_sm_fname))
  mr_t05_sm <- get(load(mr_t05_sm_fname))
  mr_t0_nsm <- get(load(mr_t0_nsm_fname))
  mr_t05_nsm <- get(load(mr_t05_nsm_fname))
  
  daily_tmax0_arg = list ( c(  
    bound =  list (c(range (cp_0_obj$predvar)   )),
    knots = list (c(knots_1)),
    coeff = list (c(cp_0_obj$coefficients)),
    varcov = list (c(cp_0_obj$vcov) )  ,
    meta_reg_sm  = list(mr_t0_sm)  ,
    meta_reg_nsm = list(mr_t0_nsm )))
  
  
  ma15_tmax05_arg =list ( c(  
    bound =  list (c(range (cp_05_obj$predvar)  )),
    knots = list (c(knots_2)),
    coeff = list (c(cp_05_obj$coefficients)),
    varcov = list (c(cp_05_obj$vcov) )  ,
    meta_reg_sm  = list(mr_t05_sm)  ,
    meta_reg_nsm = list(mr_t05_nsm )))
  
  
  cluster_0_fits <- tibble (cluster = c_cluster,
                            time_period = time_period,
                            daily_tmax0_arg = daily_tmax0_arg  )
  
  cluster_05_fits <- tibble (cluster = c_cluster,
                             ma15_tmax05_arg = ma15_tmax05_arg  )
  
  
  cluster_x_fits <- cluster_0_fits %>%  inner_join(cluster_05_fits, by = "cluster")
  # change to tibble for purrr operations later
  
  return (cluster_x_fits)
}