
# if it's not a leap year, add 1 to dates after Feb 28th.
leap_doy <- function(x) {  ifelse(yday(x) > 59 & leap_year(x) == FALSE, yday(x) + 1, yday(x)) }

get_tmean <-
  function (gcm = "CanESM2",
            rcp = "RCP85" ,
            dt_yr = 2011,
            doy_frame = doy,
            cira_folder = here::here("data/Trim/"),
            ...)
  {
    # This function loads modeled temperature data, converts dates to month/day, and 
    # converts kelvin to degrees c
    # For GCM projections. Use get_tmean_livneh for baseline
    require (dplyr) # for data cleaning
    require (tidyr) # for data cleaning
    require (data.table) # for fread and %like%
    require (purrr) # for map_dfr
    
    yrs = seq ((dt_yr - 5), (dt_yr + 5))

    ## Select out just the correct files
    gcm_folder_max <-  paste(cira_folder, gcm, "/",
                             casefold(rcp), "/tasmax", sep = "")
    gcm_files_max  <- list.files(gcm_folder_max, full.names =   TRUE)
    
    gcm_folder_min <-  paste(cira_folder, gcm, "/",
                             casefold(rcp), "/tasmin", sep = "")
    gcm_files_min  <- list.files(gcm_folder_min, full.names =   TRUE)
    
    gcm_files_max  <- map_chr(
      .x = yrs,
      .f = function (.x) {
        gcm_files_max[gcm_files_max %like% paste(.x, "0101-", .x, "1231", sep = "")]
      }
    )
    gcm_files_min  <- map_chr(
      .x = yrs,
      .f = function (.x) {
        gcm_files_min[gcm_files_min %like% paste(.x, "0101-", .x, "1231", sep = "")]
      }
    )
    # print(yrs)
    fnames = tibble (
      dt_yr = rep(dt_yr, 11),
      gcm = gcm,
      rcp = rcp,
      yr = yrs
    ) %>%
      mutate(fname_max = gcm_files_max,
             fname_min = gcm_files_min)
    read_join <-
      function(max_f = fnames$fname_max[1],
               min_f = fnames$fname_min[1]) {
        joined = fread(max_f) %>% 
          inner_join(fread(min_f),
                     by = c("date", "city")) %>% 
          mutate(tmean = (tasmin + tasmax) / 2) %>%
          select(-tasmin,-tasmax)
      }
    tmean_dt_yr <-
      map2_dfr(.x = fnames$fname_max,
               .y = fnames$fname_min,
               read_join)
    
    tmean_dt_yr <- tmean_dt_yr %>%
      mutate(
        CITYNAME = casefold(city),
        gcm = gcm,
        # may save memory to remove repeated column names, but inconvenient
        rcp = rcp,
        dt_yr = dt_yr,
        year = lubridate::year(as.Date(date)) ,
        doy =  leap_doy(as.Date(date)),
        tmean0 = tmean - 273.15
      )  %>%
      group_by(year, city, CITYNAME) %>% #gcm, rcp, dt_yr,
      nest(.key = "doy_tmean0")
    
    return (tmean_dt_yr)
  }


get_tmean_livneh <- function(year = 1973, month, cities = cities_4  ){ # year = 1973
  liv_tmin <- read_csv(paste0("/media/jdrive/projects/COOLIT13_RiskComm/Trim_Livneh_Baseline/cityweights/livneh_NAmerExt_15Oct2014_", year, month, "tmin_mean.csv"))
  liv_tmax <- read_csv(paste0("/media/jdrive/projects/COOLIT13_RiskComm/Trim_Livneh_Baseline/cityweights/livneh_NAmerExt_15Oct2014_", year, month,  "_mean.csv"))
  if(cities[1] != "all"){ liv_tmin <- liv_tmin %>% 
    filter(CITYNAME %in% cities) }
  
  tmean_dt_yr <-  liv_tmin %>% 
    left_join(liv_tmax)  %>% 
    rename(date = livneh_date)%>%
    mutate(city = CITYNAME,
           CITYNAME = casefold(CITYNAME),
           gcm = "Livneh", 
           rcp = "baseline",
           dt_yr = NA,
           year = lubridate::year(mdy_hms(date)) ,
           month = lubridate::month(mdy_hms(date)) ,
           doy = leap_doy(mdy_hms(date)),
           tmean0 = (MEAN_livneh_TminC + MEAN_livneh_TmaxC)/2)%>% 
    select(-OBJECTID , -MEAN_livneh_TminC, -MEAN_livneh_TmaxC)%>% 
    group_by(year, month, city, CITYNAME) %>% #gcm, rcp, dt_yr,
    nest(.key = "doy_tmean0")
  
  tmean_dt_yr
}