# Function to loop through the projected temperatures, apply cluster coefficients, 
# and calculate relative risk (no CI yet).
project_spline <-
  function (daily_dframe, 
            t0_args, 
            ma15_args) {
    # Make the basis first for the temperature series, then 
    # create a basis for the center point, then scale the basis vector by the centered basis. 
    daily_dframe <- daily_dframe %>%
      mutate(
        tmean0_bound = bound_tmean(tmean0,   t0_args$bound),
        tmean15_bound = bound_tmean(tmean15,   ma15_args$bound),
        rr_tmean0 = rr_calc (
          tmean = tmean0,
          knot_vec = t0_args$knots,
          bound_vec = t0_args$bound ,
          coef_mat = t0_args$coeff
        )   ,
        rr_tmean15 = rr_calc (
          tmean = tmean15,
          knot_vec = ma15_args$knots,
          bound_vec = ma15_args$bound,
          coef_mat = ma15_args$coeff
        )   ,
        rr_total = rr_tmean0 + rr_tmean15,
        rr_tmean0_bnd = rr_calc (
          tmean = tmean0_bound,
          knot_vec = t0_args$knots,
          bound_vec = t0_args$bound,
          coef_mat = t0_args$coeff
        )   ,
        rr_tmean15_bnd = rr_calc (
          tmean = tmean15_bound,
          knot_vec = ma15_args$knots,
          bound_vec = ma15_args$bound,
          coef_mat = ma15_args$coeff
        )   ,
        rr_total_bnd = rr_tmean0_bnd + rr_tmean15_bnd,
        base_death_2010_100k = total_mort / (pop2010 / 100000),
        tmean0_an_2010_100k = rr_tmean0  * base_death_2010_100k,
        tmean15_an_2010_100k = rr_tmean15 * base_death_2010_100k,
        tot_an_2010_100k = tmean0_an_2010_100k + tmean15_an_2010_100k,
        tmean0_an_2010_100k_bnd = rr_tmean0_bnd * base_death_2010_100k,
        tmean15_an_2010_100k_bnd = rr_tmean15_bnd * base_death_2010_100k,
        tot_an_2010_100k_bnd = tmean0_an_2010_100k_bnd + tmean15_an_2010_100k_bnd,
        an_tmean0  = rr_tmean0  * total_mort,
        an_tmean15 = rr_tmean15 * total_mort,
        an_total  = an_tmean0 + an_tmean15,
        an_tmean0_bnd = rr_tmean0_bnd  * total_mort,
        an_tmean15_bnd = rr_tmean15_bnd  * total_mort,
        an_total_bnd = an_tmean0_bnd + an_tmean15_bnd
      )
    return (daily_dframe)
  } 

 
project_spline_rr_av <-
  function (daily_dframe =pluck(tmean_daily,   "day_tm",8),
            cluster_list #= list( pluck(tmean_daily, "cp_out3",8))
            ) {
    # Make the basis first for the temperature series, then 
    # create a basis for the center point, then scale the basis vector by the centered basis. 
    
    cl_len <- length(cluster_list) # get the bounds for temperature cut-off (for setting max-temp/min-temp only) from the last period
    bound0 = range(pluck(cluster_list, cl_len,  "cp_0",  "predvar")) 
    bound5 = range(pluck(cluster_list, cl_len, "cp_05",  "predvar"))
 
    daily_dframe <- daily_dframe %>%
      mutate(
        tmean0_bound = bound_tmean(tmean0,   bound0),
        tmean15_bound = bound_tmean(tmean15,  bound5),
        rr_tmean0 = calc_rr_avg (
          tmean = tmean0,
          cluster_obj_list = cluster_list,
          cp_name = "cp_0",
          knot_name = "knots_1"
        )   ,
        rr_tmean15 = calc_rr_avg (
          tmean = tmean15,
          cluster_obj_list = cluster_list,
          cp_name = "cp_05",
          knot_name = "knots_2"
        )   ,
        rr_total = rr_tmean0 + rr_tmean15,
        rr_tmean0_bnd = calc_rr_avg (
          tmean = tmean0_bound,
          cluster_obj_list = cluster_list,
          cp_name = "cp_0",
          knot_name = "knots_1"
        )   ,
        rr_tmean15_bnd = calc_rr_avg (
          tmean = tmean15_bound,
          cluster_obj_list = cluster_list,
          cp_name = "cp_05",
          knot_name = "knots_2"
        )   ,
        rr_total_bnd = rr_tmean0_bnd + rr_tmean15_bnd,
        base_death_2010_100k = total_mort / (pop2010 / 100000),
        tmean0_an_2010_100k = rr_tmean0  * base_death_2010_100k,
        tmean15_an_2010_100k = rr_tmean15 * base_death_2010_100k,
        tot_an_2010_100k = tmean0_an_2010_100k + tmean15_an_2010_100k,
        tmean0_an_2010_100k_bnd = rr_tmean0_bnd * base_death_2010_100k,
        tmean15_an_2010_100k_bnd = rr_tmean15_bnd * base_death_2010_100k,
        tot_an_2010_100k_bnd = tmean0_an_2010_100k_bnd + tmean15_an_2010_100k_bnd,
        an_tmean0  = rr_tmean0  * total_mort,
        an_tmean15 = rr_tmean15 * total_mort,
        an_total  = an_tmean0 + an_tmean15,
        an_tmean0_bnd = rr_tmean0_bnd  * total_mort,
        an_tmean15_bnd = rr_tmean15_bnd  * total_mort,
        an_total_bnd = an_tmean0_bnd + an_tmean15_bnd
      )
    return (daily_dframe)
  } 


# in progress functions commented out to avoid errors
project_spline_mcmc <- function (daily_dframe = pluck(df_comp2, "day_tm", 1)
                                 , t0_args =pluck(df_comp2, "daily_arg", 1)
                                 , ma15_args =pluck(df_comp2, "ma15_arg", 1) 
                                 ) {
  # add ci to project spline funtion (in progress; alternate version below)
   
  t0_coef_sim =  t0_args$coeff_sim 
  t0_knot =  t0_args$knots 
  t0_bound =  t0_args$bound 
 
  ma15_coef_sim =   ma15_args$coeff_sim 
  ma15_knot =  ma15_args$knots 
  ma15_bound =  ma15_args$bound 
 
  daily_dframe <- data.frame(
    date = rep(daily_dframe$date, nrow(t0_coef_sim) ),
    stringsAsFactors = F) %>%
    mutate( 
     rr_tmean0 =     rr_calc (
      tmean =    daily_dframe$tmean0  ,
      knot_vec = t0_knot,
      bound_vec = t0_bound ,
      coef_mat =  t(t0_coef_sim )
      )  ,
      rr_tmean15 = rr_calc (
        tmean = daily_dframe$tmean15 ,
        knot_vec = ma15_knot,
        bound_vec = ma15_bound,
        coef_mat = t(ma15_coef_sim)
      )   ,
      rr_total = rr_tmean0 + rr_tmean15
          ) %>%
    inner_join(daily_dframe[, c("date", "doy", "total_mort", "tmean0" )], by = "date")  %>%
    mutate(
      an_tmean0  = rr_tmean0  * total_mort,
      an_tmean15 = rr_tmean15 * total_mort,
      an_total  = an_tmean0 + an_tmean15, 
      tmp_rng = case_when(tmean0<t0_knot[1] & tmean0>t0_bound[1]~ -0.5, # cold
                          tmean0<t0_bound[1] ~ -1 , # very cold
                          tmean0>t0_knot[2]  & tmean0<t0_bound[2]~  0.5, # warm 
                          tmean0>t0_bound[2]~  1 , # hot
                          TRUE ~ 0) # else mid-range
      )     %>%
    select(-total_mort, -tmean0) %>% 
    group_by(date) %>% 
    mutate(sim_id = row_number()) %>%
    ungroup()%>% 
    group_by(sim_id)%>%
    nest(.key = "ar_sim")
}

 