# Summarization functions for aggregating the projections after they are produced. 
# These functions currently do not weight values.

re_center_rr <- function(x,y){x = x/y} # for re-centering RR in form of 1.1 or 0.9. 
re_center_ar <- function(x,y){x = x-y} # for re-centering RR in form of 1.1 or 0.9.

baseline_mean <- function(dframe = baseline_compiled_city_mean_out, min_year = 2003, tm_name = "day_tm_4") {
  # calculate the mean day of year projected value (AR, AN, tmean) for baseline period projections
  dframe %>% 
    filter(year >=min_year)  %>%  
    dplyr::select(cluster, city,  CITYNAME, FIPS_txt, year, contains(tm_name) ) %>%
    unnest() %>% ungroup() %>% 
    select(-date , -year, -month )%>%
    group_by(cluster, city,  CITYNAME, FIPS_txt,  doy) %>%
    summarise_all("mean" ) 
}


gcm_mean_fun <- function(gcmframe = gcm_compiled_city_mean_out, 
                         baseframe = baseline_y34_proj_avgs, 
                         tm_name = "day_tm_av") { 
  # calculate the mean day of year values for projected temperatures used in conjunction with 
  # baseline_mean to produce proj-hind values. Final data frame includes baseline projections, 
  # GCM-based projections, and the differences between the two. Distinguished in gcm_base column
  
  dTc_compiled_gcm_city<-  gcmframe %>%    
    dplyr::select(cluster, city,  CITYNAME, FIPS_txt, dT_c, year,  contains(tm_name)   )  %>% 
    unnest() %>% 
    ungroup()  %>%
    select( -year,-date, -dt_yr, -rcp , -tmean) %>% 
    group_by(gcm, cluster, city,  CITYNAME, FIPS_txt, dT_c, doy, pop2010, total_mort, base_death_2010_100k) %>%
    summarise_all("mean")    %>%
    inner_join(baseframe, suffix = c(".proj", ".base"), 
               by = c("cluster", "city", "CITYNAME", "FIPS_txt", "pop2010",  "doy", "total_mort", "base_death_2010_100k" ) )  %>%
    select(gcm, cluster, city,CITYNAME, FIPS_txt,  dT_c,  doy, pop2010, total_mort, base_death_2010_100k,  everything()) %>%
    pivot_longer(cols = tmean0.proj:an_total_bnd.base, 
                 names_to = "tm_var", values_to = "value") %>%   
    separate(tm_var, c("tm_var" , "gcm_base"), "\\.", extra = "merge" )  %>%
    pivot_wider(names_from = gcm_base, values_from  =  "value" )  %>%
    mutate(dif =  proj-base )  %>%
    pivot_longer(proj:dif, names_to = "gcm_base", values_to = "value") %>%
    pivot_wider(names_from = tm_var, values_from = value) }

calc_city_ci <- function(df_comp = ct , 
                         base_min_mid_year = c(2003, 2008), 
                         cluster_f = cluster_short,  
                         time_window = "season", # also "year", "doy"
                         city_lcase = "atlanta" 
){ 
  # get CI by time window; currently outputs all options other than doy of year. Used after 
  # project_spline_mcmc to perform preliminary aggregation on mcmc and avoid memory overuee
  
  if(!is.na(base_min_mid_year[1])) {
    df_comp <- df_comp %>%  # for baseline, filter to desired year period
      filter(year >= base_min_mid_year[1])%>%
      mutate(dt_yr=base_min_mid_year[2]) %>% 
      dplyr::select(-day_tm, -starts_with("cp_out"))} 
 
  df_comp  <- df_comp %>% 
    unnest() %>%
    select( cluster, FIPS_txt ,  CITYNAME,  gcm,    dT_c, 
            year,   date,    doy, 
           tmean0, tmean15, # tmean0_bound, tmean15_bound, 
           total_mort# pop2010, base_death_2010_100k
            ) %>%
    # filter(CITYNAME == city_lcase) %>% 
    ungroup() %>%
    group_by(cluster, FIPS_txt ,  CITYNAME,  gcm,    dT_c , year) %>% 
    nest( .key =  "day_tm" ) %>% 
    left_join(cluster_f, by = "cluster")   %>% 
    mutate(day_tm  = pmap(list(day_tm,   daily_arg, ma15_arg  ),
                          ~project_spline_mcmc (..1, ..2, ..3 )),
           ) %>% 
    select(cluster,  CITYNAME, gcm ,  dT_c , time_period, FIPS_txt , year,  day_tm)  %>% 
    unnest() %>%  unnest() %>% ungroup()  
 

  if(time_window == "doy" ) {
    agvars = c("gcm" ,  "dT_c" , "time_period", "FIPS_txt",  "cluster",   "CITYNAME", "sim_id",  "doy"  ) 
  }

  if(time_window == "season" ) {
  agvars = c("gcm" ,  "dT_c" ,"time_period", "FIPS_txt",  "cluster",   "CITYNAME", "sim_id", "year", "season" , "tmp_rng" ) 
  season_labs <- data.frame(doy = 1:366) %>%
    mutate(
      season = case_when(
        doy > 335 | doy < 61 ~ 1,
        # winter
        doy > 60 & doy < 183 ~ 2,
        # spring
        doy > 182 & doy < 275 ~ 3,
        # summer
        doy > 274 & doy < 336 ~ 4,
        # fall
        TRUE ~ 0
      ))
      df_comp <- df_comp %>%  
        left_join(season_labs, by = "doy")  %>% 
    select(-doy, -date)   }
 
if(time_window == "year" ) {
  agvars = c("gcm" ,  "dT_c" ,"time_period", "FIPS_txt",  "cluster",   "CITYNAME", "sim_id", "year", "season" , "tmp_rng") 
  df_comp <- df_comp %>% mutate(season = 12 ) %>% select(-doy, -date)   }


if(time_window %in% c("year" , "season" )) { 

  season_sum <- 
  df_comp %>% # get sum of year or season for the wider time windows
    mutate( tmp_rng = -9, day_ct = 1) %>% 
    group_by_at( vars(one_of(agvars)) ) %>%
    summarise_at( vars(-group_cols()), "sum") %>% ungroup() %>%
    mutate_at(vars(contains("rr_")      # c("tmean0", "tmean15" # ,  "tmean0_bound", "tmean15_bound", "pop2010", "total_mort", "base_death_2010_100k") 
                     ), 
              ~ ./day_ct) 

  year_sums <- 
    df_comp %>% mutate(season = 12,  tmp_rng = -9, day_ct = 1) %>% # get sum of all seasons across year (this will be close if all the aggregation is done first and summed, but the CI will not be quite right)
    group_by_at( vars(one_of(agvars)) ) %>% 
    summarise_at( vars(-group_cols()), "sum")%>% ungroup() %>%
    mutate_at(vars(contains("rr_")  # c("tmean0", "tmean15" #, "tmean0_bound", "tmean15_bound",  "pop2010", "total_mort", "base_death_2010_100k" )
                     ),
              ~ ./day_ct) 
 
  temp_sums <- 
    df_comp %>% 
    mutate(season = 0, day_ct = 1) %>% # get sum of temperatures across year (this will be close if all the aggregation is done first and summed, but the CI will not be quite right)
    group_by_at( vars(one_of(agvars)) ) %>% 
    summarise_at( vars(-group_cols()), "sum")%>% ungroup() %>%
    mutate_at(vars(contains("rr_")   #, c("tmean0", "tmean15" #, "tmean0_bound", "tmean15_bound",  "pop2010", "total_mort", "base_death_2010_100k" ) 
                   ),
              ~ ./day_ct)
 
   df_comp <- season_sum  %>%  bind_rows(year_sums) %>%  bind_rows(temp_sums)%>% select(-day_ct) %>% unique()

}
 
  # 
  df_comp %>% # get mean across simulations, without year-to-year variation
    group_by_at(vars(one_of(agvars[agvars!="year"]))) %>%
    select(-year) %>%
    summarise_at( vars(-group_cols()), "mean")%>% ungroup()
 
}

gcm_mean_fun_ci <- function(gcmframe = atl_proj, baseframe = atl_base ,  time_window = "season", drop_bnd = TRUE 
                            ) { 
  # calculate the mean for projected-hindcast based on output of project-spline_mcmc and city.
  # final data frame includes baseline projections, GCM-based projections, and the differences between the two.
  # Distinguished in gcm_base column

  if(!drop_bnd & time_window == "doy"){stop("bounding columns add excessive calculation time; update function")} 
  
  if(time_window %in% c("season", "year") ){ 
    drop_vars_base = c("gcm",  "dT_c" ) }
  
  
  if(!drop_bnd & time_window == "doy"){stop("bounding columns add excessive calculation time; update function")} 
  
  if(drop_bnd) {
    baseframe <- baseframe    %>% select(-one_of(drop_vars_base)) %>%     select(-ends_with("_bnd"), -ends_with("_bound")) 
    gcmframe <- gcmframe  %>%    select(-ends_with("_bnd"), -ends_with("_bound"))  
  }
 
  if(time_window == "year") { 
  baseframe <- baseframe  %>%  mutate(year = 0) %>%
    select(FIPS_txt:sim_id, one_of(time_window) , everything() )
  gcmframe <- gcmframe   %>%  mutate(year = 0) %>% 
    select(gcm:sim_id, one_of(time_window) , everything() )
  }
  gcmframe<- gcmframe  %>%  
    select(gcm:one_of(time_window) , everything() ) %>%
    inner_join(baseframe, suffix = c(".proj", ".base"), 
               by = c("time_period", "sim_id", "cluster", "FIPS_txt", "CITYNAME", "tmp_rng", time_window ) ) %>% 
    pivot_longer(cols = rr_tmean0.proj:last_col(), 
                 names_to = "tm_var", values_to = "value")  %>%    
    separate(tm_var, c("tm_var" , "gcm_base"), "\\.", extra = "merge" )  %>% 
    pivot_wider(names_from = gcm_base, values_from  =  "value" )  %>%
    mutate(dif =  proj-base )  %>%
    dplyr::select(-proj, -base  ) 
  
  # print(gcmframe %>% filter(is.na(dif)|is.nan(dif)) %>% head())
  
  gcmframe<-  gcmframe %>% 
      group_by_at(vars(one_of( c("dT_c", "time_period", "cluster", "FIPS_txt", "CITYNAME", "tmp_rng", time_window, "tm_var"))))  %>%
      summarise(n_samp = n(),
                n_na = sum(is.na(dif)),
                mean_val = mean(dif), 
                lci_50=quantile(dif, probs=0.25, na.rm = TRUE),
                uci_50=quantile(dif, probs=0.75, na.rm = TRUE),
                lci_66=quantile(dif, probs=0.17, na.rm = TRUE),
                uci_66=quantile(dif, probs=0.83, na.rm = TRUE),
                lci_95=quantile(dif, probs=0.025, na.rm = TRUE),
                uci_95=quantile(dif, probs=0.975, na.rm = TRUE)  
      ) 
  gcmframe 
 
}


summarise_temp_c <- function(dframe , ...)
{
  # allows different grouping variables defined as variable length arguments
  group_var <- enquos(...)
  print(group_var)
  
  dframe <- dframe %>%
    group_by(!!!group_var) %>% #!!! group_var
    summarise(
      mean_daily_c = mean (tmean0),
      sd_daily_c = sd(tmean0),
      max_daily_c = max(tmean0),
      min_daily_c = min(tmean0),
      mean_ma15_c = mean(tmean15),
      sd_ma15_c =  sd(tmean15),
      max_ma15_c = max(tmean15),
      min_ma15_c = min(tmean15)
    )
  return (dframe)
}


summarise_mean_rr <- function(dframe = proj_rr_daily, 
                              rr_vars = c(rr_tmean0 = "rr_tmean0", rr_tmean15 = "rr_tmean15", rr_tmean0_bnd= "rr_tmean0_bnd", rr_tmean15_bnd = "rr_tmean15_bnd"), 
                              ...) 
{ # allows different grouping variables defined as variable length arguments  
  group_var <- enquos(...)
  
  dframe <- dframe %>% rename (!!!rr_vars)
  
  if(any(!grepl("total", rr_vars)) )  {dframe <- dframe  %>% rename (!!!rr_vars)  %>%
    mutate(rr_total = rr_tmean0 + rr_tmean15,
           rr_total_bnd = rr_tmean0_bnd + rr_tmean15_bnd)
  }
  
  dframe <- dframe %>%
    group_by(!!! group_var) %>%
    summarise(
      mean_rr_total = mean(rr_total),
      sd_rr_total = sd(rr_total),
      mean_rr_total_bnd = mean(rr_total_bnd),
      sd_rr_total_bnd = sd(rr_total_bnd)
    )
  
  return (dframe)
}

summarise_mean_an <- function(dframe ,
                              an_vars = c(an_tmean0 = "an_tmean0", an_tmean15 ="an_tmean15", an_tmean0_bnd = "an_tmean0_bnd", an_tmean15_bnd ="an_tmean15_bnd") , 
                              ...) 
{ # allows different grouping variables defined as variable length arguments
  group_var <- enquos(...)
  
  dframe <- dframe %>% rename (!!!an_vars) %>%mutate()

  dframe <- dframe %>% 
    group_by(!!! group_var) %>%
    summarise(baseline_proj_mort = mean (total_mort), # use mean to extract original projected baseline again
              mean_an_total = mean(an_total),
              sd_an_total = sd(an_total),
              mean_an_total_bnd = mean(an_total_bnd),
              sd_an_total_bnd = sd(an_total_bnd)) }



summarise_sum_an <- function(dframe , 
                             an_vars = c(total_mort = total_mort, 
                                         an_tmean0 = "an_tmean0", an_tmean15 ="an_tmean15", 
                                         an_tmean0_bnd = "an_tmean0_bnd", an_tmean15_bnd ="an_tmean15_bnd") ,  
                             ...) 
{ # ... allows different grouping variables defined as variable length arguments  ...  
  group_var <- enquos(...)
  dframe <- dframe %>% rename (!!!an_vars)
  
  if(any(!grepl("an_total", an_vars)) )  {
    dframe <- dframe  %>% rename (!!!an_vars)  %>%
    mutate(an_total = an_tmean0  + an_tmean15,
           an_total_bnd = an_tmean0_bnd  + an_tmean15_bnd)
  }
  
  
  dframe <- dframe %>% 
    group_by(!!! group_var) %>%
    summarise(baseline_proj_mort = sum(total_mort), 
              sum_an_total = sum(an_total),
              sum_an_total_bnd = sum(an_total_bnd) ) }

