
# Adapted from Gasparinni 2012 Stat med paper code; 
# C.Lay modified to add names and model descriptors for simpler manuscript table production
# FUNCTION TO COMPUTE THE STATISTICS FOR EACH MODEL
# available at  https://github.com/gasparrini/2012_gasparrini_StatMed_Rcodedata/
# note that mvmeta will soon be completely replaced by mixmeta, and this function may become obsolete.

ftab <- function(m = time_lag0, mref=int_lag0, tests = c("LR", "wald")) {
  # HETEROGENEITY AND IC STATS
   
  q <- qtest(m)
  het <- data.frame(Q= q$Q[1],
                    df = q$df[1],
                    Q_p = q$pvalue[1],
                    I2 = (q$Q[1]-q$df[1])/q$Q[1]*100)
  if(het$I2 <0){het$I2=0}
  if(m$method != "reml"){ het <- cbind(het, 
                                      data.frame( AIC = AIC(m),
                                     BIC= BIC(m)))}
  # LR TEST (ONLY FOR META-REGRESSION with nested model comparison)
  if("LR" %in% tests & !is.null(mref)& m$method != "reml") {
   
    lrstat <- -2*(logLik(mref)-logLik(m))[1]
    df <- attr(logLik(m),"df")-attr(logLik(mref),"df")
    pvalue <- 1-pchisq(lrstat,df)
    lr <- data.frame(LR = lrstat, LR_df = df, LR_p = pvalue, stringsAsFactors = F)
  }
  # WALD TEST (ONLY FOR META-REGRESSION with nested model comparison)
  if("wald" %in% tests &!is.null(mref)& m$method != "reml") {
     
    coef <- coef(m)[-grep("Int",names(coef(m)))]
    vcov <- vcov(m)[-grep("Int",names(coef(m))),-grep("Int",names(coef(m)))]
    waldstat <- coef%*%solve(vcov)%*%coef
    df <- length(coef)
    pvalue <- 1-pchisq(waldstat,df)
    wald <- data.frame(wald = waldstat, wald_df = df, wald_p = pvalue, stringsAsFactors = F)
  }
  # RESULTS
  if(class(m) =="mvmeta"){
  labs = data.frame(mod = paste(rownames(m$coefficients), collapse =  " + ") ,
                    ref = paste(rownames(mref$coefficients), collapse =  " + ") ) 
  } else  if(class(m) == "mixmeta"){ 
    labs = data.frame(mod =  paste(m$call$formula[3], collapse ="" ) ,
                      ref = paste( mref$call$formula[3], collapse ="" ) )  
    } else {stop("model class not supported")}
  
  if(m$method != "reml") { 
    if(!is.null(mref) ) {
    return(cbind(labs, het,lr,wald))
    } else {
      return(cbind( labs,  het, data.frame( LR=NA, LR_df=NA, LR_p=NA, wald=NA, wald_df=NA, wald_p=NA, stringsAsFactors = F) )) } 
  } else { 
    if(!is.null(mref) ) {
    return(cbind(labs, het ))
    } else {
    return(cbind( labs,  het  )) } 
    }
}