### cluster_1_meta_reg.r
## 2020-03-04
## Claire Lay, Abt Assoc.
## Correct data with shifted names, and run meta-regression on cluster 1 output from Alina Vodonos-Zilberg.
## Sourced from 2020-03-03_QA_Manuscript_meta-reg.rmd

### FIrst read in the meta-regression data. 
cluster_1_dat <- read_csv(here("output/vodonos_out/2019-09-02-Temperature-and-Mortality-master/Meta-regression/Cluster1/meta_data.csv"))
# census population values; air conditioning from census as well; temperatures from Livneh
# census and AC from a single county within the urban area for each city; reconsider


### First drop richmond in the first time period as it will not be used for analysis.
cluster_1_dat <- cluster_1_dat %>% 
  filter(!( city == "richmond" & time == 1)) 

### Cormat on raw:
cluster_1_dat %>% 
  select( -fips_sm) %>%
  select_if(is.numeric) %>%
  cor()  
## Winter and summer mean almost entirely correlated; likely to have issues; should not both go into same models
## Total population and population over 65, likely also to cause multicollinarity
## Air conditioning and time are at .73 if time handled as continuous var. CHECK

cluster_1_dat <- cluster_1_dat %>% 
  mutate(time_con =  time - mean(time), 
         time = factor(time , levels = c(3,1,2,4)) ,
         totpop1 = totalpop/mean(totalpop),
         popover65_1 =  popover65/mean(popover65))  

### Cormat again
cor_c1_tab <- cluster_1_dat %>% 
  select(-fips_sm)%>%
  select_if(is.numeric) %>%
  cor()  
cor_c1_tab %>% knitr::kable()%>%
  print()

#### Get the fitted parameters and variance covariance matrices for this cluster
cluster_1_parms <- data.frame(time_period = 1:4) %>% 
  mutate( parms  = map(time_period, ~load_parms(here (paste0("output/vodonos_out/2019-09-02-Temperature-and-Mortality-master/Meta-regression/Cluster1/mv_cl1_y", .x, ".Rdata")))))

cl1_tp1_ymat_1 <- ymat_get(tp = 1, dframe = cluster_1_parms, ymat_name = "ymat_1")[1:36,] ##drop 'york' row for 1973 period; this appears to actually be a frame-shift. Richmond was removed from the analysis, not york, but york does not have a row in meta-data.
cit_names_correct <-  rownames(cl1_tp1_ymat_1)[c(1:27,29:36)] # Correct frame-shift
cl1_tp1_ymat_1 <- cl1_tp1_ymat_1[ c(1:27, 29:35),] # must also drop york because it is not in the meta-reg data. 
rownames(cl1_tp1_ymat_1) = cit_names_correct[1:34]

cluster_1_ymat_1 <-  
  rbind (cl1_tp1_ymat_1,
         ymat_get(tp = 2, dframe = cluster_1_parms, ymat_name = "ymat_1") ,
         ymat_get(tp = 3, dframe = cluster_1_parms, ymat_name = "ymat_1") ,
         ymat_get(tp = 4, dframe = cluster_1_parms, ymat_name = "ymat_1") )

cl1_tp1_Slist_1 <-  Slist_get(tp = 1, dframe = cluster_1_parms, Slist_name = "Slist_1")[1:35]  #drop empty york row for 1973 period
names(cl1_tp1_Slist_1) <- cit_names_correct # correct the names, removing richmond va.
cl1_tp1_Slist_1 <- cl1_tp1_Slist_1[1:34 ] # last, must also drop york because it is not in the meta-reg data. 
cluster_1_Slist_1 <-  
  c (cl1_tp1_Slist_1,
     Slist_get(tp = 2, dframe = cluster_1_parms, Slist_name = "Slist_1") ,
     Slist_get(tp = 3, dframe = cluster_1_parms, Slist_name = "Slist_1") ,
     Slist_get(tp = 4, dframe = cluster_1_parms, Slist_name = "Slist_1") ) 




#########Fit the models

int_lag0<-mvmeta(cluster_1_ymat_1     , 
                 cluster_1_Slist_1  ,
                 na.action= "na.omit", 
                 method="ml") 

time_lag0<- mvmeta(cluster_1_ymat_1~ 
                     time      , 
                   cluster_1_Slist_1 
                   , data = cluster_1_dat , 
                   na.action= "na.omit", method="ml")

mod_ac_int_lag0<-mvmeta(cluster_1_ymat_1~ 
                          time +
                          air_cond *
                          summer_mean   , 
                   cluster_1_Slist_1 
                   , data = cluster_1_dat , 
                   na.action= "na.omit", method="ml")
mod_ac_int_lag0  

modac_lag0<-mvmeta(cluster_1_ymat_1~ 
                     time +
                     air_cond + 
                     summer_mean  , 
                   cluster_1_Slist_1 
                   , data = cluster_1_dat , 
                   na.action= "na.omit", method="ml")
modac_lag0  


mod1_lag0<-mvmeta(cluster_1_ymat_1~ 
                    summer_mean + 
                    time +
                    totpop1 + 
                    popover65_1 , 
                  cluster_1_Slist_1 
                  , data = cluster_1_dat , 
                  na.action= "na.omit", method="ml")
mod1_lag0 # vodonos mod1
## matches vodonos output; logLik 791.1650
# Safe to get air_con ests



mod2_lag0 <-  mvmeta(cluster_1_ymat_1~ 
                       time +
                       totpop1 + 
                       popover65_1    , 
                       cluster_1_Slist_1 
                       , data = cluster_1_dat , 
                       na.action= "na.omit", method="ml")


summary(mod2_lag0) ## ALso matches vodonos

 

cl1_mod_lag0_lst <- list(  time_lag0=time_lag0,mod1_lag0=mod1_lag0, mod2_lag0=mod2_lag0, mod_ac_int_lag0= mod_ac_int_lag0, modac_lag0=modac_lag0  ) #all_int_lag0=all_int_lag0 , singular computational system


meta_reg_tab_cluster1_lag0 <- cl1_mod_lag0_lst  %>%  
  map_dfr( ~ ftab( m =  . , mref = int_lag0), .id = "model_name")

meta_reg_tab_cluster1_lag0 <- ftab  (m =  int_lag0, mref = NULL ) %>%
  mutate(model_name = "int_lag0")%>%
bind_rows(meta_reg_tab_cluster1_lag0 )%>%
  mutate(cluster = 1 , lag = "lag 0") %>% 
  select(model_name, cluster, lag, mod, ref, Q, df_q = df, Q_p = Q_p, I2, AIC, BIC)

meta_reg_tab_cluster1_lag0
## get just the references and the best fits
meta_reg_tab_cluster1_lag0[ unique (c(1,2, which.min(meta_reg_tab_cluster1_lag0$BIC),  
                                      which.min(meta_reg_tab_cluster1_lag0$AIC),
                                      which.min(meta_reg_tab_cluster1_lag0$I2))) ,]

save(cl1_mod_lag0_lst, file =here("output/y4-final-manuscript-output/2020-03-03-Manu-Meta-reg/Cluster1/cl1_mod_lag0_lst.Rdata"))

# choose the best fit
# choose the best fit
summary(mod_ac_int_lag0)
# reml for final fit params
mod_ac_int_lag0_reml <- update(mod_ac_int_lag0, method = "reml")
summary(mod_ac_int_lag0_reml)
#######

#####  create prediction frame
# new_data_lag0 <- cluster_1_dat %>% 
#   top_n(3)%>% 
#   mutate(time_rev = 0,
#          time  = factor(4),
#          air_cond  = 100,
#          summer_mean =  c(mean(summer_mean), mean(summer_mean)+1, mean(summer_mean)+4) ,
#          totpop1 = min(totpop1)*1.1         ,
#          popover65_1 = min(popover65_1)*1.1)%>% 
#   select(time, time_rev, air_cond, summer_mean, totpop1, popover65_1) %>% 
#   as.data.frame()


# 
# lag0_pred <- predict (mod_ac_int_lag0_reml,
#                       newdata = new_data_lag0) # provides overall predictions  
# rr_lag0 <- rr_calc  ( tmean = 10:40 , 
#                       coef_mat = t(lag0_pred ) ,
#                       center_val = 15.6, # default across all clusters
#                       degree_val = 2,
#                       knot_vec = pluck (cluster_fits  , "daily_arg",1 , "knots"),   
#                       bound_vec = pluck (cluster_fits , "daily_arg",1 , "bound")) 
# 
# plot(rep( 10:40, 3) ,  rr_lag0) 
# 
# 
# lag0_blup <-blup(mod3_lag0, newdata = new_data_lag0,  pi = TRUE, pi.level = .66) # provides random by-city predictions
# 
# rr_lag0_city <- rr_calc  ( tmean = 10:40 , 
#                            coef_mat = t(lag0_blup$blup) ,
#                            center_val = 15.6, # default across all clusters
#                            degree_val = 2,
#                            knot_vec = pluck (cluster_fits  , "daily_arg",1 , "knots"),   
#                            bound_vec = pluck (cluster_fits , "daily_arg",1 , "bound")) 
# plot(rep( 10:40, 142) , rr_lag0)
  
#############MA15

cluster_1_ymat2 <-  ymat_get(tp = 1, dframe = cluster_1_parms, ymat_name = "ymat_2") [1:35,] #drop empty york row for 1973 period
rownames(cluster_1_ymat2) <- cit_names_correct # correct the names, removing richmond va.
cluster_1_ymat2 <- cluster_1_ymat2[1:34,] # last, must also drop york because it is not in the meta-reg data. 

cluster_1_ymat2 <-  
  rbind (cluster_1_ymat2,#drop york for 1973 period
         ymat_get(tp = 2, dframe = cluster_1_parms, ymat_name = "ymat_2") ,
         ymat_get(tp = 3, dframe = cluster_1_parms, ymat_name = "ymat_2") ,
         ymat_get(tp = 4, dframe = cluster_1_parms, ymat_name = "ymat_2") )

cl1_tp1_Slist2 <-  Slist_get(tp = 1, dframe = cluster_1_parms, Slist_name = "Slist_2") [1:35 ]  #drop empty york row for 1973 period
names(cl1_tp1_Slist2) <- cit_names_correct # correct the names, removing richmond va.
cl1_tp1_Slist2 <- cl1_tp1_Slist2[1:34 ] # last, must also drop york because it is not in the meta-reg data. 

cluster_1_Slist2 <-  
  c ( cl1_tp1_Slist2 ,#drop york for 1973 period
      Slist_get(tp = 2, dframe = cluster_1_parms, Slist_name = "Slist_2") ,
      Slist_get(tp = 3, dframe = cluster_1_parms, Slist_name = "Slist_2") ,
      Slist_get(tp = 4, dframe = cluster_1_parms, Slist_name = "Slist_2") ) 


int_ma15<-mvmeta(cluster_1_ymat2     , 
                 cluster_1_Slist2  ,
                 na.action= "na.omit", method="ml") 

time_ma15<- mvmeta(cluster_1_ymat2~ 
                    time      , 
                   cluster_1_Slist2 
                   , data = cluster_1_dat , 
                   na.action= "na.omit", method="ml")
 

mod1_ma15<-mvmeta(cluster_1_ymat2~ 
                    time +
                    winter_mean +
                    totpop1 + 
                    popover65_1 , 
                  cluster_1_Slist2 
                  , data = cluster_1_dat , 
                  na.action= "na.omit", method="ml")
mod1_ma15 # vodonos mod1
 

mod2_ma15<-  mvmeta(cluster_1_ymat2~ 
                       time +
                       totpop1 + 
                       popover65_1    , 
                    cluster_1_Slist2 
                     , data = cluster_1_dat , 
                     na.action= "na.omit", method="ml") 
summary(mod2_ma15) ##  vodonos mod2 but with summer mean removed; rho .95 with winter mean; should not be in same model

mod3_ma15<-  mvmeta(cluster_1_ymat2~ 
                      time +
                      winter_mean *
                      popover65_1    , 
                    cluster_1_Slist2 
                    , data = cluster_1_dat , 
                    na.action= "na.omit", method="ml") 
summary(mod3_ma15) # 
  
### get output
cl1_mod_ma15_lst <- list(  time_ma15=time_ma15,mod1_ma15=mod1_ma15, mod2_ma15=mod2_ma15, mod3_ma15= mod3_ma15  ) #all_int_lag0=all_int_lag0 , singular computational system
save(cl1_mod_ma15_lst, file =here("output/y4-final-manuscript-output/2020-03-03-Manu-Meta-reg/Cluster1/cl1_mod_ma15_lst.Rdata"))


meta_reg_tab_cluster1_ma15 <- cl1_mod_ma15_lst  %>%  
  map_dfr( ~ ftab( m =  . , mref = int_ma15), .id = "model_name")

meta_reg_tab_cluster1_ma15 <- ftab  (m =  int_ma15, mref = NULL ) %>%
  mutate(model_name = "int_ma15")%>%
bind_rows(meta_reg_tab_cluster1_ma15 )%>%
  mutate(cluster = 1 , lag = "MA15") %>% 
  select(model_name, cluster, lag, mod, ref, Q, df_q = df, Q_p = Q_p, I2, AIC, BIC)

meta_reg_tab_cluster1_ma15
## get just the references and the best fits
meta_reg_tab_cluster1_ma15[ unique (c(1,2, which.min(meta_reg_tab_cluster1_ma15$BIC),  
                                      which.min(meta_reg_tab_cluster1_ma15$AIC),
                                      which.min(meta_reg_tab_cluster1_ma15$I2))) ,]

meta_reg_tab_cluster1 <- meta_reg_tab_cluster1_lag0 %>% bind_rows(meta_reg_tab_cluster1_ma15)


#drop used model objects.
rm_models <- c(names(cl1_mod_lag0_lst), names(cl1_mod_ma15_lst))
rm(rm_models)