### cluster_3_meta_reg.r
## 2020-03-04
## Claire Lay, Abt Assoc.
## Correct data with shifted names, and run meta-regression on cluster 3 output from Alina Vodonos-Zilberg.
## Sourced from 2020-03-03_QA_Manuscript_meta-reg.rmd


## Read in predictors
cluster_3_dat <- read_csv(here("output/vodonos_out/2019-09-02-Temperature-and-Mortality-master/Meta-regression/Cluster3/meta_data.csv"))


### Cormat on raw:
cluster_3_dat %>% 
  select( -fips_sm) %>%
  select_if(is.numeric) %>%
  cor()  

cluster_3_dat <- cluster_3_dat %>% 
  filter(!(time ==1 & city == "stlouis"))%>%
  mutate(time_rev=  time -4, 
         time = factor(time , levels = c(3,1,2,4)) ,
         totpop1 = totalpop/mean(totalpop),
         popover65_1 =  popover65/mean(popover65))  

cluster_3_dat %>% 
  select( -fips_sm) %>%
  select_if(is.numeric) %>%
  cor() %>% knitr::kable()%>%
  print()### total population and pop over 65 very very tight; summer and winter mean are close. 
#####

cluster_3_parms <- data.frame(time_period = 1:4) %>% 
  mutate( parms  = map(time_period, ~load_parms(here (paste0("output/vodonos_out/2019-09-02-Temperature-and-Mortality-master/Meta-regression/Cluster3/mv_cl3_y", .x, ".Rdata")))))
 

cluster_3_ymat_1 <- ymat_get(tp = 1, dframe = cluster_3_parms, ymat_name = "ymat_1") ##drop 'wichita' row for 1973 period; this appears to actually be a frame-shift. stlouis was removed from the analysis 
cit_names_correct <-  rownames(cluster_3_ymat_1)[c(1:19,21:23)] # Correct frame-shift
cluster_3_ymat_1 <- cluster_3_ymat_1[c(1:19,21:23),] # must also drop wichita because it is not in the meta-reg data. 
rownames(cluster_3_ymat_1) = cit_names_correct 
 
cluster_3_ymat_1 <-  
  rbind (cluster_3_ymat_1  , 
         ymat_get(tp = 2, dframe = cluster_3_parms, ymat_name = "ymat_1") ,
         ymat_get(tp = 3, dframe = cluster_3_parms, ymat_name = "ymat_1") ,
         ymat_get(tp = 4, dframe = cluster_3_parms, ymat_name = "ymat_1") )

 
cl3_tp1_Slist_1 <-  Slist_get(tp = 1, dframe = cluster_3_parms, Slist_name = "Slist_1")[c(1:19,21:23)]  #drop empty  row for 1973 period
names(cl3_tp1_Slist_1) <- cit_names_correct # correct the names

cluster_3_Slist_1 <-  
  c ( cl3_tp1_Slist_1 , 
     Slist_get(tp = 2, dframe = cluster_3_parms, Slist_name = "Slist_1") ,
     Slist_get(tp = 3, dframe = cluster_3_parms, Slist_name = "Slist_1") ,
     Slist_get(tp = 4, dframe = cluster_3_parms, Slist_name = "Slist_1") ) 


############FIT  

int_lag0<-mvmeta(cluster_3_ymat_1     , 
                 cluster_3_Slist_1  ,
                 na.action= "na.omit", 
                 method="ml") 

time_lag0<- mvmeta(cluster_3_ymat_1~ 
                     time      , 
                   cluster_3_Slist_1 
                   , data = cluster_3_dat , 
                   na.action= "na.omit", method="ml")

mod_ac_int_lag0<-mvmeta(cluster_3_ymat_1~ 
                          time +
                          air_cond *
                          summer_mean   , 
                        cluster_3_Slist_1 
                        , data = cluster_3_dat , 
                        na.action= "na.omit", method="ml")
 

modac_lag0<-mvmeta(cluster_3_ymat_1~ 
                     time +
                     air_cond + 
                     summer_mean  , 
                   cluster_3_Slist_1 
                   , data = cluster_3_dat , 
                   na.action= "na.omit", method="ml")
 

mod1_lag0<-mvmeta(cluster_3_ymat_1~ 
                    summer_mean + 
                    time +
                    popover65_1 , 
                  cluster_3_Slist_1 
                  , data = cluster_3_dat , 
                  na.action= "na.omit", method="ml")
 


mod2_lag0 <-  mvmeta(cluster_3_ymat_1~ 
                       time +
                       popover65_1    , 
                     cluster_3_Slist_1 
                     , data = cluster_3_dat , 
                     na.action= "na.omit", method="ml")

 


### Concatenate results
cl3_mod_lag0_lst <- list(  time_lag0=time_lag0,mod1_lag0=mod1_lag0, mod2_lag0=mod2_lag0, 
                           mod_ac_int_lag0= mod_ac_int_lag0, modac_lag0=modac_lag0  ) #all_int_lag0=all_int_lag0 , singular computational system


meta_reg_tab_cluster_3_lag0 <- cl3_mod_lag0_lst  %>%  
  map_dfr( ~ ftab( m =  . , mref = int_lag0), .id = "model_name")


meta_reg_tab_cluster_3_lag0 <- ftab  (m =  int_lag0, mref = NULL ) %>%
  mutate(model_name = "int_lag0")%>%
  bind_rows(meta_reg_tab_cluster_3_lag0 )%>%
  mutate(cluster = 1 , lag = "lag 0") %>% 
  select(model_name, cluster, lag, mod, ref, Q, df_q = df, Q_p = Q_p, I2, AIC, BIC)

meta_reg_tab_cluster_3_lag0
## get just the references and the best fits
meta_reg_tab_cluster_3_lag0[ unique (c(1,2, which.min(meta_reg_tab_cluster_3_lag0$BIC),  
                                      which.min(meta_reg_tab_cluster_3_lag0$AIC),
                                      which.min(meta_reg_tab_cluster_3_lag0$I2))) ,]

save(cl3_mod_lag0_lst, file =here("output/y4-final-manuscript-output/2020-03-03-Manu-Meta-reg/Cluster3/cl3_mod_lag0_lst.Rdata"))
############ 
 

#############
 
  
 

#############MA15
cluster_3_ymat2 <-  ymat_get(tp = 1, dframe = cluster_3_parms, ymat_name = "ymat_2") # D
cluster_3_ymat2 <- cluster_3_ymat2[c(1:19,21:23),] # must also drop wichita because it is not in the meta-reg data. 
rownames(cluster_3_ymat2) = cit_names_correct 

cluster_3_ymat2 <-  
  rbind (cluster_3_ymat2 , 
         ymat_get(tp = 2, dframe = cluster_3_parms, ymat_name = "ymat_2") ,
         ymat_get(tp = 3, dframe = cluster_3_parms, ymat_name = "ymat_2") ,
         ymat_get(tp = 4, dframe = cluster_3_parms, ymat_name = "ymat_2") )

cl3_tp1_Slist_2 <-  Slist_get(tp = 1, dframe = cluster_3_parms, Slist_name = "Slist_1")[c(1:19,21:23)]  #drop empty  row for 1973 period
names(cl3_tp1_Slist_1) <- cit_names_correct # correct the names

cluster_3_Slist2 <-  
  c ( cl3_tp1_Slist_2 ,  
     Slist_get(tp = 2, dframe = cluster_3_parms, Slist_name = "Slist_2") ,
     Slist_get(tp = 3, dframe = cluster_3_parms, Slist_name = "Slist_2") ,
     Slist_get(tp = 4, dframe = cluster_3_parms, Slist_name = "Slist_2") ) 


 #####FIT MA15


int_ma15<-mvmeta(cluster_3_ymat2     , 
                 cluster_3_Slist2  ,
                 na.action= "na.omit", method="ml") 

time_ma15<- mvmeta(cluster_3_ymat2~ 
                    time      , 
                   cluster_3_Slist2 
                   , data = cluster_3_dat , 
                   na.action= "na.omit", method="ml")
 

mod1_ma15<-mvmeta(cluster_3_ymat2~ 
                    time +
                    summer_mean + 
                    winter_mean +
                    popover65_1 , 
                  cluster_3_Slist2 
                  , data = cluster_3_dat , 
                  na.action= "na.omit", method="ml")
 

mod2_ma15<-  mvmeta(cluster_3_ymat2~ 
                       time + 
                       popover65_1    , 
                    cluster_3_Slist2 
                     , data = cluster_3_dat , 
                     na.action= "na.omit", method="ml") 

mod3_ma15<-  mvmeta(cluster_3_ymat2~ 
                      time +
                      winter_mean *
                      popover65_1    , 
                    cluster_3_Slist2 
                    , data = cluster_3_dat , 
                    na.action= "na.omit", method="ml") 
 

### get output
cl3_mod_ma15_lst <- list(  time_ma15=time_ma15,mod1_ma15=mod1_ma15, mod2_ma15=mod2_ma15, mod3_ma15= mod3_ma15  ) #all_int_lag0=all_int_lag0 , singular computational system
save(cl3_mod_ma15_lst, file =here("output/y4-final-manuscript-output/2020-03-03-Manu-Meta-reg/Cluster3/cl3_mod_ma15_lst.Rdata"))


meta_reg_tab_cluster_3_ma15 <- cl3_mod_ma15_lst  %>%  
  map_dfr( ~ ftab( m =  . , mref = int_ma15), .id = "model_name")

meta_reg_tab_cluster_3_ma15 <- ftab  (m =  int_ma15, mref = NULL ) %>%
  mutate(model_name = "int_ma15")%>%
  bind_rows(meta_reg_tab_cluster_3_ma15 )%>%
  mutate(cluster = 1 , lag = "MA15") %>% 
  select(model_name, cluster, lag, mod, ref, Q, df_q = df, Q_p = Q_p, I2, AIC, BIC)

meta_reg_tab_cluster_3_ma15
## get just the references and the best fits
meta_reg_tab_cluster_3_ma15[ unique (c(1,2, which.min(meta_reg_tab_cluster_3_ma15$BIC),  
                                      which.min(meta_reg_tab_cluster_3_ma15$AIC),
                                      which.min(meta_reg_tab_cluster_3_ma15$I2))) ,]

meta_reg_tab_cluster_3 <- meta_reg_tab_cluster_3_lag0 %>% bind_rows(meta_reg_tab_cluster_3_ma15)

#drop used model objects.
rm_models <- c(names(cl3_mod_lag0_lst), names(cl3_mod_ma15_lst)) 
rm(rm_models)