### cluster_6_meta_reg.r
## 2020-03-04
## Claire Lay, Abt Assoc.
## Correct data with shifted names, and run meta-regression on cluster 6 output from Alina Vodonos-Zilberg.
## Sourced from 2020-03-03_QA_Manuscript_meta-reg.rmd


## Read in predictors

cluster_6_dat <- read_csv(here("output/vodonos_out/2019-09-02-Temperature-and-Mortality-master/Meta-regression/Cluster6/meta_data.csv"))

cluster_6_parms <- data.frame(time_period = 1:4) %>% 
  mutate( parms  = map(time_period, ~load_parms(here (paste0("output/vodonos_out/2019-09-02-Temperature-and-Mortality-master/Meta-regression/Cluster6/mv_cl6_y", .x, ".Rdata")))))
 

cluster_6_ymat_1 <-  
  rbind (ymat_get(tp = 1, dframe = cluster_6_parms, ymat_name = "ymat_1")  , 
         ymat_get(tp = 2, dframe = cluster_6_parms, ymat_name = "ymat_1") ,
         ymat_get(tp = 3, dframe = cluster_6_parms, ymat_name = "ymat_1") ,
         ymat_get(tp = 4, dframe = cluster_6_parms, ymat_name = "ymat_1") )

cluster_6_Slist_1 <-  
  c (Slist_get(tp = 1, dframe = cluster_6_parms, Slist_name = "Slist_1")  , 
     Slist_get(tp = 2, dframe = cluster_6_parms, Slist_name = "Slist_1") ,
     Slist_get(tp = 3, dframe = cluster_6_parms, Slist_name = "Slist_1") ,
     Slist_get(tp = 4, dframe = cluster_6_parms, Slist_name = "Slist_1") ) 


cluster_6_dat <- cluster_6_dat %>% 
  mutate(time_con =  time - mean(time), 
         time = factor(time , levels = c(3,1,2,4)) ,
         totpop1 = totalpop/mean(totalpop),
         popover65_1 =  popover65/mean(popover65))  
 

cluster_6_dat %>% 
  select(-fips_sm)%>%
  select_if(is.numeric) %>%
  cor()  %>% 
  knitr::kable()%>%
  print()#### total and popover65 together likely to caluse some trouble. 

int_lag0<-mvmeta(cluster_6_ymat_1     , 
                 cluster_6_Slist_1  ,
                 na.action= "na.omit", method="ml") 

time_lag0<- mvmeta(cluster_6_ymat_1~ 
                     time      , 
                   cluster_6_Slist_1 
                   , data = cluster_6_dat , 
                   na.action= "na.omit", method="ml")


modac_int_lag0<-mvmeta(cluster_6_ymat_1~ 
                         time +
                         air_cond *
                         summer_mean , 
                       cluster_6_Slist_1 
                       , data = cluster_6_dat , 
                       na.action= "na.omit", method="ml")



modac_lag0<-mvmeta(cluster_6_ymat_1~ 
                     time +
                     air_cond +
                     summer_mean , 
                   cluster_6_Slist_1 
                   , data = cluster_6_dat , 
                   na.action= "na.omit", method="ml")


mod1_lag0<-mvmeta(cluster_6_ymat_1~ 
                    time +
                    summer_mean + 
                    winter_mean +
                    air_cond  , 
                  cluster_6_Slist_1 
                  , data = cluster_6_dat , 
                  na.action= "na.omit", method="ml")
mod1_lag0 # vodonos mod1
 


mod2_lag0 <-  mvmeta(cluster_6_ymat_1~ 
                       time +
                       air_cond +
                       totpop1 + 
                       popover65_1    , 
                       cluster_6_Slist_1 
                       , data = cluster_6_dat , 
                       na.action= "na.omit", method="ml")


summary(mod2_lag0) ## ALso matches vodonos


mod3_lag0 <-  mvmeta(cluster_6_ymat_1~ 
                       time +
                       totpop1 + 
                       popover65_1    , 
                       cluster_6_Slist_1 
                     , data = cluster_6_dat , 
                     na.action= "na.omit", method="ml")

 

  

### Concatenate results
cl6_mod_lag0_lst <- list(  time_lag0=time_lag0,
                           modac_lag0=modac_lag0 ,
                           modac_int_lag0 = modac_int_lag0,
                           mod1_lag0=mod1_lag0,  
                           mod2_lag0=mod2_lag0,
                           mod3_lag0 = mod3_lag0 ) #all_int_lag0=all_int_lag0 , singular computational system


meta_reg_tab_cluster_6_lag0 <- cl6_mod_lag0_lst  %>%  
  map_dfr( ~ ftab( m =  . , mref = int_lag0), .id = "model_name")

meta_reg_tab_cluster_6_lag0 <- ftab  (m =  int_lag0, mref = NULL ) %>%
  mutate(model_name = "int_lag0")%>%
  bind_rows(meta_reg_tab_cluster_6_lag0 )%>%
  mutate(cluster = 1 , lag = "lag 0") %>% 
  select(model_name, cluster, lag, mod, ref, Q, df_q = df, Q_p = Q_p, I2, AIC, BIC)

meta_reg_tab_cluster_6_lag0
## get just the references and the best fits
meta_reg_tab_cluster_6_lag0[ unique (c(1,2, which.min(meta_reg_tab_cluster_6_lag0$BIC),  
                                      which.min(meta_reg_tab_cluster_6_lag0$AIC),
                                      which.min(meta_reg_tab_cluster_6_lag0$I2))) ,] %>% 
  print()


save(cl6_mod_lag0_lst, file =here("output/y4-final-manuscript-output/2020-03-03-Manu-Meta-reg/Cluster6/cl6_mod_lag0_lst.Rdata"))

#############MA15

  
#############MA15
cluster_6_ymat2 <-  
  rbind (ymat_get(tp = 1, dframe = cluster_6_parms, ymat_name = "ymat_2") , 
         ymat_get(tp = 2, dframe = cluster_6_parms, ymat_name = "ymat_2") ,
         ymat_get(tp = 3, dframe = cluster_6_parms, ymat_name = "ymat_2") ,
         ymat_get(tp = 4, dframe = cluster_6_parms, ymat_name = "ymat_2") )

cluster_6_Slist2 <-  
  c (Slist_get(tp = 1, dframe = cluster_6_parms, Slist_name = "Slist_2") , 
     Slist_get(tp = 2, dframe = cluster_6_parms, Slist_name = "Slist_2") ,
     Slist_get(tp = 3, dframe = cluster_6_parms, Slist_name = "Slist_2") ,
     Slist_get(tp = 4, dframe = cluster_6_parms, Slist_name = "Slist_2") ) 

int_ma15<-mvmeta(cluster_6_ymat2     , 
                 cluster_6_Slist2  ,
                 na.action= "na.omit", method="ml") 

time_ma15<- mvmeta(cluster_6_ymat2~ 
                    time      , 
                   cluster_6_Slist2 
                   , data = cluster_6_dat , 
                   na.action= "na.omit", method="ml")
 
moda_ma15<-mvmeta(cluster_6_ymat2~ 
                    time +
                    summer_mean + 
                    winter_mean +
                    air_cond + 
                   # totpop1 + 
                    popover65_1 , 
                  cluster_6_Slist2 
                  , data = cluster_6_dat , 
                  na.action= "na.omit", method="ml")
 

mod1_ma15<-mvmeta(cluster_6_ymat2~ 
                    time +
                    summer_mean + 
                    winter_mean +
                    air_cond   , 
                  cluster_6_Slist2 
                  , data = cluster_6_dat , 
                  na.action= "na.omit", method="ml")
 
 

mod2_ma15<-  mvmeta(cluster_6_ymat2~ 
                       time +
                      air_cond      , 
                      cluster_6_Slist2 
                     , data = cluster_6_dat , 
                     na.action= "na.omit", method="ml") 
summary(mod2_ma15) ## ALso matches vodonos

mod3_ma15<-  mvmeta(cluster_6_ymat2~ 
                      time +
                      winter_mean *
                      popover65_1    , 
                    cluster_6_Slist2 
                    , data = cluster_6_dat , 
                    na.action= "na.omit", method="ml") 

 
### get output for concatenation
cl6_mod_ma15_lst <- list(  time_ma15=time_ma15, 
                           moda_ma15 = moda_ma15, 
                           mod1_ma15=mod1_ma15, 
                           mod2_ma15=mod2_ma15, 
                           mod3_ma15= mod3_ma15  ) #all_int_lag0=all_int_lag0 , singular computational system
save(cl6_mod_ma15_lst, file =here("output/y4-final-manuscript-output/2020-03-03-Manu-Meta-reg/Cluster6/cl6_mod_ma15_lst.Rdata"))


meta_reg_tab_cluster_6_ma15 <- cl6_mod_ma15_lst  %>%  
  map_dfr( ~ ftab( m =  . , mref = int_ma15), .id = "model_name")

meta_reg_tab_cluster_6_ma15 <- ftab  (m =  int_ma15, mref = NULL ) %>%
  mutate(model_name = "int_ma15")%>%
  bind_rows(meta_reg_tab_cluster_6_ma15 )%>%
  mutate(cluster = 1 , lag = "MA15") %>% 
  select(model_name, cluster, lag, mod, ref, Q, df_q = df, Q_p = Q_p, I2, AIC, BIC)

meta_reg_tab_cluster_6_ma15
## get just the references and the best fits
meta_reg_tab_cluster_6_ma15[ unique (c(1,2, which.min(meta_reg_tab_cluster_6_ma15$BIC),  
                                       which.min(meta_reg_tab_cluster_6_ma15$AIC),
                                       which.min(meta_reg_tab_cluster_6_ma15$I2))) ,] %>% 
  print()

meta_reg_tab_cluster_6 <- meta_reg_tab_cluster_6_lag0 %>% bind_rows(meta_reg_tab_cluster_6_ma15)

rm_models <- c(names(cl6_mod_lag0_lst), names(cl6_mod_ma15_lst))
rm(rm_models)