# Script R, meta-smoothing US, Francesco Nordio - Antonella Zanobetti

options("object.size"=2000000000000)
#setwd("Z:/Alina/Temperature_US_Cities")
setwd("/media/qnap3/Alina/Temperature_US_Cities")

library(foreign)
library(survival)
library(splines)
library (MASS)
library(nlme) 
library(mgcv)
library(dlnm) 
library(splines) 
library(tsModel)
library(dplyr)
library(readr)
library(ggplot2)

data<-readRDS("work_data/cmort_temperature.all.rds")
names(data)
summary(data$Year)
data<-subset(data, data$Cluster==1 )
names(data)
data$TEMP_C<-I(data$MEAN_livneh_TminC+data$MEAN_livneh_TmaxC)/2 # Mean Temperature
summary(data$TEMP_C)
data$n_date <- seq.int(nrow(data))


# Remove Ricmond 
remove<-subset(data, data$CITYNAME=="richmond" & data$Year<=1982)
data<-anti_join(data, remove)


data$years.block[data$Year>=1973 & data$Year<1980] <- "years1"
data$years.block[data$Year>=1980 & data$Year<1990] <- "years2"
data$years.block[data$Year>=1990 & data$Year<1998] <- "years3"
data$years.block[data$Year>=1998 & data$Year<2007] <- "years4"
data$years.block[data$Year>=2007 & data$Year<=2013] <-"years5"

names(data)
descriptive<-data%>%
  group_by(years.block, Cluster)%>%
  summarise(tot.mean=mean(tot),
            tot.min=min(tot),
            tot.max=max(tot),
            TmaxC.mean=mean(MEAN_livneh_TmaxC),
            TmaxC.mean.min=min(MEAN_livneh_TmaxC),
            TmaxC.mean.max=max(MEAN_livneh_TmaxC),
            TminC.mean=mean(MEAN_livneh_TminC),
            TminC.min=min(MEAN_livneh_TminC),
            TminC.max=max(MEAN_livneh_TminC),
            Tmean=mean(TEMP_C),
            Tmean.min=min(TEMP_C),
            Tmean.max=max(TEMP_C))

write.csv(descriptive, 'Results/Cluster1/descriptive.cl1.csv')
freq=hist(data$TEMP_C, breaks = 50, xlab = "Temperature (C)", main = "", col="lightblue")
freq.table<-data.frame(temperature=freq$mids, counts=freq$counts)
write.csv(freq.table, "Results/Cluster1/freq.table.csv", row.names = F)

#data<-subset(data, data$years.block=="years1")
#data<-subset(data, data$years.block=="years2")
#data<-subset(data, data$years.block=="years3")
#data<-subset(data, data$years.block=="years4")
data<-subset(data, data$years.block=="years5")


####################################################################
# CITY-LEVEL META-PREDICTORS

# CITY-LEVEL META-PREDICTORS (problem with anchor)

mylist <- split(data, data$city_name) 
list<-unique(data$city_name)

# DEFINE THE SUBSET OF CITIES, WITH MOVING AVERAGE OF TEMPERATURE AT LAG 1-5 and LAG 0
for(i in seq(mylist)) mylist[[i]]$TEMP_C_l1 <- ((lag(mylist[[i]]$TEMP_C,1)))        # Lag 1
for(i in seq(mylist)) mylist[[i]]$TEMP_C_l2 <- ((lag(mylist[[i]]$TEMP_C,2)))        # Lag 1
for(i in seq(mylist)) mylist[[i]]$TEMP_C_l3 <- ((lag(mylist[[i]]$TEMP_C,3)))        # Lag 1
for(i in seq(mylist)) mylist[[i]]$TEMP_C_l4 <- ((lag(mylist[[i]]$TEMP_C,4)))        # Lag 1
for(i in seq(mylist)) mylist[[i]]$TEMP15    <- runMean(mylist[[i]]$TEMP_C,1:5)      # MA  15

meandeath <- sapply(mylist, function(x) mean(x$tot,na.rm=T))
meantmean <- sapply(mylist, function(x) mean(x$TEMP_C,na.rm=T))
mintmean  <- sapply(mylist, function(x)  min(x$TEMP_C,na.rm=T))
maxtmean  <- sapply(mylist, function(x)  max(x$TEMP_C,na.rm=T))

Cluster_1_mod <- data.frame(row.names=list, meandeath = meandeath, meantmean = meantmean, mintmean = mintmean, maxtmean = maxtmean)
summary(Cluster_1_mod)
m <- length(list)


# TEMPERATURE RANGES (FOR LAG0)
ranges_1 <- t(sapply(mylist,function(x) range(x$TEMP_C,na.rm=T)))

# TEMPERATURE RANGES (FOR LAG 1-5)
ranges_2 <- t(sapply(mylist,function(x) range(x$TEMP15,na.rm=T)))


# COMPUTE 25TH-75TH PERCENTILES OF META-VARIABLES
percmod <- round(sapply(Cluster_1_mod,function(x) {
  quantile(x,c(75,25)/100,na.rm=T)
}),1)

# DEFINE THE AVERAGE RANGE, CENTERING POINT, DEGREE AND TYPE OF THE SPLINE
# (THESE PARAMETERS CAN BE CHANGED BY THE USER FOR ADDITIONAL ANALYSES)
cen_1 <- 15.6  # Centering at min
cen_2 <- 15.6  # Centering at mean

bound_1 <- colMeans(ranges_1)
bound_2 <- colMeans(ranges_2)

degree <- 2
fun <- "bs"


####################################################################
# MODEL SELECTION
#   COMPUTING TIME: ~1MIN (IN A 2.66GHz-4GBRAM PC UNDER WINDOWS)
####################################################################

# DEFINE PERCENTILES FOR KNOTS (SPLINE 1 - Lag 0)

allperc <- c(5,10,27.5,35,50,65,72.5,90,95)

# DEFINE KNOTS AS AVERAGE PERCENTILES

allknots_1 <- rowMeans(sapply(mylist,function(x) {
  quantile(x$TEMP_C,allperc/100,na.rm=T)
}))

allknots_2 <- rowMeans(sapply(mylist,function(x) {
  quantile(x$TEMP15,allperc/100,na.rm=T)
}))

# COMBINATIONS OF KNOTS FOR INCREASING DF

comb_1 <- list(c(3,7),c(2,5,8),c(1,4,6,9),c(1,3,5,7,9))
comb_2 <- list(c(3,7),c(2,5,8),c(1,4,6,9),c(1,3,5,7,9))

# BUILT THE MATRIX OF Q-AIC VALUES FOR EACH CITY/COMBINATION

qaicmat_1 <- matrix(0,m,length(comb_1),dimnames=list(list,NULL))
qaicmat_2 <- matrix(0,m,length(comb_2),dimnames=list(list,NULL))


########################################################################
# RUN THE MODEL FOR EACH CITY, FOR EACH COMBINATION (First Spline Lag 0)

# LOOP FOR CITIES
system.time(
  for(i in seq(m)) {
    
    # LOAD DATA
    data <- mylist[[i]]
    df_count <-(round(length(na.omit(data$TEMP_C))/365)*6)+1
    
    # LOOP FOR KNOTS COMBINATIONS
    for(j in seq(comb_1)) {
      
      # SELECT THE KNOTS
      
      tempknots_1 <- allknots_1[comb_1[[j]]]
      
      
      # CREATE THE CENTERED SPLINE
      # WARNING FOR PREDICTION BEYOND BOUNDARIES SUPPRESSED
      
      suppressWarnings(
        btmean0 <- onebasis(data$TEMP_C,fun=fun,degree=degree,
                            knots=tempknots_1,bound=bound_1,cen=cen_1)
      
      )
      
      # RUN THE MODEL
      
      model <- glm(tot ~ btmean0 + ns(TEMP_C_l1, df=5) + as.factor(dow) + ns(n_date,df=df_count),
                         family=quasipoisson(), data)
      
      
      # COMPUTE AND SAVE THE Q-AIC VALUE
      loglik <- sum(dpois(model$y,model$fitted.values,log=TRUE))
      phi <- summary(model)$dispersion
      
      qaicmat_1[i,j] <- -2*loglik + 2*summary(model)$df[3]*phi
      
    }
  })


########################################################################
# RUN THE MODEL FOR EACH CITY, FOR EACH COMBINATION (Second Spline MA15)

# LOOP FOR CITIES
system.time(
  for(i in seq(m)) {
    
    # LOAD DATA
    data <- mylist[[i]]
    df_count <-(round(length(na.omit(data$TEMP_C))/365)*6)+1
    
    # LOOP FOR KNOTS COMBINATIONS
    for(j in seq(comb_2)) {
      
      # SELECT THE KNOTS
      
      tempknots_2 <- allknots_2[comb_2[[j]]]
      
      
      # CREATE THE CENTERED SPLINE
      # WARNING FOR PREDICTION BEYOND BOUNDARIES SUPPRESSED
      
      suppressWarnings(
        btmean15 <- onebasis(data$TEMP15,fun=fun,degree=degree,
                             knots=tempknots_2,bound=bound_2,cen=cen_2)
        
      )
      
      # RUN THE MODEL
      
      model <- glm(tot ~ btmean15 + as.factor(dow) + ns(n_date,df=df_count),
                   family=quasipoisson(), data)
      
      
      # COMPUTE AND SAVE THE Q-AIC VALUE
      
      loglik <- sum(dpois(model$y,model$fitted.values,log=TRUE))
      phi <- summary(model)$dispersion
      
      qaicmat_2[i,j] <- -2*loglik + 2*summary(model)$df[3]*phi
      
    }
  })

####################################################################


# RESULTS

# SUM THE Q-AIC ACROSS CITIES
qaictot_1 <- colSums(qaicmat_1)
qaictot_2 <- colSums(qaicmat_2)


# CHOSEN DF, PERCENTILES AND KNOTS AT MINIMUM Q-AIC

(df_1 <- length(comb_1[[which.min(qaictot_1)]]) + 1 + (fun=="bs")*(degree-1))
(df_2 <- length(comb_2[[which.min(qaictot_2)]]) + 1 + (fun=="bs")*(degree-1))


(perc_1 <- allperc[comb_1[[which.min(qaictot_1)]]])
(perc_2 <- allperc[comb_2[[which.min(qaictot_2)]]])

(knots_1 <- allknots_1[comb_1[[which.min(qaictot_1)]]])
(knots_2 <- allknots_2[comb_2[[which.min(qaictot_2)]]])


# BUILT OBJECTS WHERE RESULTS WILL BE STORED:
#   ymat IS THE MATRIX FOR THE OUTCOME PARAMETERS
#   Slist IS THE LIST WITH (CO)VARIANCE MATRICES

ymat_1 <- matrix(NA,m,df_1,dimnames=list(list,paste("spl",seq(df_1),sep="")))
ymat_2 <- matrix(NA,m,df_2,dimnames=list(list,paste("spl",seq(df_2),sep="")))

Slist_1 <- vector("list",m)
Slist_2 <- vector("list",m)

names(Slist_1) <- list
names(Slist_2) <- list

#SAVE THE JOB
save.image(file = "Results/Cluster1/cluster1_q-aic.RData")
####################################################################
# RUN THE FIRST-STAGE ANALYSIS

# Load the saved job from the previous stage
load("/media/qnap3/Alina/Temperature_US_Cities/codes/Analysis_by_Clusters/cluster1_q-aic.RData")

system.time(
  for(i in seq(m)) {
    
    # LOAD
    data <- mylist[[i]]
    df_count <-(round(length(na.omit(data$TEMP_C))/365)*6)+1
    
    # CREATE THE CENTERED SPLINE NB: KNOTS AND BOUNDARIES FIXED AT SAME VALUES
    # WARNING FOR PREDICTION BEYOND BOUNDARIES SUPPRESSED
    suppressWarnings(
      btmean0  <- onebasis(data$TEMP_C,fun=fun,degree=degree,
                           knots=knots_1,bound=bound_1,cen=cen_1)    
    )
    
    suppressWarnings(
      btmean15 <- onebasis(data$TEMP15,fun=fun,degree=degree,
                           knots=knots_2,bound=bound_2,cen=cen_2)    
    )
    
    # RUN THE MODEL
    model <- glm(tot ~ btmean0 + btmean15 + as.factor(dow) + ns(n_date,df=df_count),family=quasipoisson(),data)
    
    # EXTRACT AND SAVE THE RELATED COEF AND VCOV
    # WARNING FOR PREDICTION BEYOND BOUNDARIES SUPPRESSED
    
    suppressWarnings(
      predtmean0 <- crosspred(btmean0,model)
    )
    
    suppressWarnings(
      predtmean15 <- crosspred(btmean15,model)
    )
    
    ymat_1[i,] <- predtmean0$coef
    ymat_2[i,] <- predtmean15$coef
    
    Slist_1[[i]] <- predtmean0$vcov
    Slist_2[[i]] <- predtmean15$vcov
  })

#



# LOAD THE PACKAGES (mvmeta PACKAGE IS ASSUMED TO BE INSTALLED)
library(mvmeta)

# MULTIVARIATE META-ANALYSIS
ymat_1
Slist_1
ymat_1<-na.omit(ymat_1) ## Removing NA
ymat_2<-na.omit(ymat_2) ## Removing NA
Slist_1<-Filter(Negate(is.null), Slist_1)  ## Removing NA
Slist_2<-Filter(Negate(is.null), Slist_2)  ## Removing NA

mv_1 <- mvmeta(ymat_1,Slist_1,method="ml")
summary(mv_1)

mv_2 <- mvmeta(ymat_2,Slist_2,method="ml")
summary(mv_2)

####################################################################
# CREATE BASIS FOR PREDICTION
####################################################################

# BASIS USED TO PREDICT TEMPERATURE, EQUAL TO THAT USED FOR ESTIMATION
#   NOTE: INTERNAL AND BOUNDARY KNOTS PLACED AT SAME VALUES AS IN ESTIMATION
#   NOTE: SPLINE CENTERED ON THE SAME VALUE AS IN ESTIMATION

tmean0   <- seq(bound_1[1],bound_1[2],length=30)

btmean0 <- onebasis(tmean0,fun=fun,degree=degree,knots=knots_1,
                    bound=bound_1,cen=cen_1)

tmean15   <- seq(bound_2[1],bound_2[2],length=30)

btmean15 <- onebasis(tmean15,fun=fun,degree=degree,knots=knots_2,
                     bound=bound_2,cen=cen_2)


####################################################################
# PREDICTION FROM MODELS
####################################################################

# USE OF crosspred TO PREDICT THE EFFECTS FOR THE CHOSEN VALUES

# PREDICTION FROM SIMPLE META-ANALYSES WITH NO PREDICTORS

cp_0_years5 <- crosspred(btmean0, coef=coef(mv_1),vcov=vcov(mv_1),model.link="log", by=0.1)
cp_05_years5 <- crosspred(btmean15,coef=coef(mv_2),vcov=vcov(mv_2),model.link="log",by=0.1)

save(cp_0_years5, cp_05_years5, knots_1, knots_2,   file="Results/Cluster1/cp.cluster1.years5.Rdata") 


# My Graphs

# First Spline

par(mfcol=c(2,1), mar=c(5,4,1,1)+0.1, cex.axis=0.9)

plot(cp1$predvar, (cp1$matRRfit/min(cp1$matRRfit)), ylab="RR",xlab="Temperature (C)", type="l", col="darkred", lwd=1, ylim=c(0.8,1.4), xlim=c(-20,40))
par(new=T)

plot(cp1$predvar, (cp1$matRRhigh/min(cp1$matRRfit)), type="l", col="blue", lty=2, xlab=NA, ylab=NA, ylim=c(0.8,1.4), xlim=c(-20,40))
par(new=T)

plot(cp1$predvar, (cp1$matRRlow/min(cp1$matRRfit)),  type="l", col="blue", lty=2, xlab=NA, ylab=NA, ylim=c(0.8,1.4), xlim=c(-20,40))
points(round(knots_1,1),(cp1$allRRfit/min(cp1$matRRfit))[as.character(round(knots_1,1))],pch=19,cex=0.6, col="darkred")
title(main = "Cluster 1 - POOLED - Lag 0")

# Second Spline

plot(cp2$predvar, (cp2$matRRfit/min(cp2$matRRfit)), ylab="RR",xlab="Temperature (C)", type="l", col="darkred", lwd=1, ylim=c(0.8,1.4), xlim=c(-20,40))
par(new=T)

plot(cp2$predvar, (cp2$matRRhigh/min(cp2$matRRfit)), type="l", col="blue", lty=2, xlab=NA, ylab=NA, ylim=c(0.8,1.4), xlim=c(-20,40))
par(new=T)

plot(cp2$predvar, (cp2$matRRlow/min(cp2$matRRfit)),  type="l", col="blue", lty=2, xlab=NA, ylab=NA, ylim=c(0.8,1.4), xlim=c(-20,40))
points(round(knots_2,1),(cp2$allRRfit/min(cp2$matRRfit))[as.character(round(knots_2,1))],pch=19,cex=0.6, col="darkred")
title(main = "Cluster 1 - POOLED - MA15")


# Save the Job

save.image(file="C:\\Users\\FNORDIO\\Desktop\\NNDC Climate Data Online\\Final Data Analysis\\Workspace\\Cluster_1.RData")



# PLOT ALL THE YEARS

load("/media/qnap3/Alina/Temperature_US_Cities/Results/Cluster1/cp.cluster1.years1.Rdata")
load("/media/qnap3/Alina/Temperature_US_Cities/Results/Cluster1/cp.cluster1.years2.Rdata")
load("/media/qnap3/Alina/Temperature_US_Cities/Results/Cluster1/cp.cluster1.years3.Rdata")
load("/media/qnap3/Alina/Temperature_US_Cities/Results/Cluster1/cp.cluster1.years4.Rdata")
load("/media/qnap3/Alina/Temperature_US_Cities/Results/Cluster1/cp.cluster1.years5.Rdata")


jpeg("Results/Cluster1/CL1-POOLED-LAG0.jpg", width = 500, height = 350)

plot(cp_0_years1$predvar, (cp_0_years1$matRRfit/min(cp_0_years1$matRRfit)), ylab="RR",xlab="Temperature (C)", type="l", col="green4", lwd=1, ylim = c(0.8,1.6))
par(new=T)
plot(cp_0_years2$predvar, (cp_0_years2$matRRhigh/min(cp_0_years2$matRRfit)), type="l", col="cornflowerblue", lty=1, xlab=NA, ylab=NA, xaxt='n', yaxt='n', ylim = c(0.8,1.6))
par(new=T)
plot(cp_0_years3$predvar, (cp_0_years3$matRRlow/min(cp_0_years3$matRRfit)),  type="l", col="yellow", lty=1, xlab=NA, ylab=NA, xaxt='n', yaxt='n', ylim = c(0.8,1.6))
par(new=T)
plot(cp_0_years4$predvar, (cp_0_years4$matRRlow/min(cp_0_years4$matRRfit)),  type="l", col="mediumpurple1", lty=1, xlab=NA, ylab=NA, xaxt='n', yaxt='n', ylim = c(0.8,1.6))
par(new=T)
plot(cp_0_years5$predvar, (cp_0_years5$matRRlow/min(cp_0_years5$matRRfit)),  type="l", col="salmon1", lty=1, xlab=NA, ylab=NA, xaxt='n', yaxt='n', ylim = c(0.8,1.6))
title(main = "Cluster 1 - POOLED - Lag 0")

legend("topleft",  cex=0.8,                     
       legend=c("1973-1980", "1980-1990", "1990-1998","1998-2007","2007-2013"),      
       col=c("green4","cornflowerblue","yellow","mediumpurple1","salmon1"),                     
       lty=c(1,1,1,1,1,1),                     
       lwd=c(1,1,1,1,1,1))

dev.off()

jpeg("Results/Cluster1/Cluster 1 - POOLED - MA15.jpg", width = 500, height = 350)

plot(cp_05_years1$predvar, (cp_05_years1$matRRfit/min(cp_05_years1$matRRfit)), ylab="RR",xlab="Temperature (C)", type="l", col="green4", lwd=1, ylim = c(0.8,1.6))
par(new=T)
plot(cp_05_years2$predvar, (cp_05_years2$matRRhigh/min(cp_05_years2$matRRfit)), type="l", col="cornflowerblue", lty=1, xlab=NA, ylab=NA, xaxt='n', yaxt='n', ylim = c(0.8,1.6))
par(new=T)
plot(cp_05_years3$predvar, (cp_05_years3$matRRlow/min(cp_05_years3$matRRfit)),  type="l", col="yellow", lty=1, xlab=NA, ylab=NA, xaxt='n', yaxt='n', ylim = c(0.8,1.6))
par(new=T)
plot(cp_05_years4$predvar, (cp_05_years4$matRRlow/min(cp_05_years4$matRRfit)),  type="l", col="mediumpurple1", lty=1, xlab=NA, ylab=NA, xaxt='n', yaxt='n', ylim = c(0.8,1.6))
par(new=T)
plot(cp_05_years5$predvar, (cp_05_years5$matRRlow/min(cp_05_years5$matRRfit)),  type="l", col="salmon1", lty=1, xlab=NA, ylab=NA, xaxt='n', yaxt='n', ylim = c(0.8,1.6))
title(main = "Cluster 1 - POOLED - MA15")

legend("topright",  cex=0.8,                     
       legend=c("1973-1980", "1980-1990", "1990-1998","1998-2007","2007-2013"),      
       col=c("green4","cornflowerblue","yellow","mediumpurple1","salmon1"),                     
       lty=c(1,1,1,1,1,1),                     
       lwd=c(1,1,1,1,1,1))

dev.off()


knots_1
knots_2
