---
title: 'QA: RR X-center value'
author: "Claire Lay"
output:
  html_document:
    keep_md: TRUE
    self_contained: FALSE
    df_print: paged
    toc: TRUE
    toc_depth: 5 
    code_folding: hide
---





### Load in R packages 

```r
# lpath <- "/home/ad.abt.local/layc/R/library" # assign library for user w/o admin priveleges on ACE3
# .libPaths(lpath)

#library(chron)
library(tictoc) # for system time
library(readxl) # for reading in excel
library(readr)  # for csv
library(survival) # from original vodonos code. Loaded for compatibility
library(splines) # for splines
library(MASS)  # for mvmeta, likely
#library(nlme) 
library(mgcv) # from original vodonos code. Loaded for compatibility
```

```
## Loading required package: nlme
```

```
## This is mgcv 1.8-31. For overview type 'help("mgcv-package")'.
```

```r
library(dlnm) # from original vodonos code. Loaded for compatibility
```

```
## This is dlnm 2.3.9. For details: help(dlnm) and vignette('dlnmOverview').
```

```r
library(tsModel) # from original vodonos code. Loaded for compatibility
```

```
## Time Series Modeling for Air Pollution and Health (0.6)
```

```r
library(mvmeta) # from original vodonos code. Loaded for compatibility
```

```
## This is mvmeta 0.4.11. For an overview type: help('mvmeta-package').
```

```r
library(here) # convenience for filepaths dynamic
```

```
## here() starts at /home/ad.abt.local/layc/cira3-mortality-home
```

```r
here <- here::here # to avoid overwrite
library(data.table) # fread for faster read (read.table takes >15 min)
library(tidyverse)
```

```
## ── Attaching packages ───────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────── tidyverse 1.3.0 ──
```

```
## ✓ ggplot2 3.2.1     ✓ dplyr   0.8.3
## ✓ tibble  2.1.3     ✓ stringr 1.4.0
## ✓ tidyr   1.0.0     ✓ forcats 0.4.0
## ✓ purrr   0.3.3
```

```
## ── Conflicts ──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────── tidyverse_conflicts() ──
## x dplyr::between()   masks data.table::between()
## x dplyr::collapse()  masks nlme::collapse()
## x dplyr::filter()    masks stats::filter()
## x dplyr::first()     masks data.table::first()
## x dplyr::lag()       masks stats::lag()
## x dplyr::last()      masks data.table::last()
## x dplyr::select()    masks MASS::select()
## x purrr::transpose() masks data.table::transpose()
```

```r
library(lubridate)
```

```
## 
## Attaching package: 'lubridate'
```

```
## The following object is masked _by_ '.GlobalEnv':
## 
##     here
```

```
## The following objects are masked from 'package:data.table':
## 
##     hour, isoweek, mday, minute, month, quarter, second, wday, week,
##     yday, year
```

```
## The following object is masked from 'package:here':
## 
##     here
```

```
## The following object is masked from 'package:base':
## 
##     date
```

```r
select <- dplyr::select # to re-assign select to specify dplyr as is more commonly used than raster and MASS functions in script below.
# Temporary fix due to changes in nest/unnest syntax (deprecated arguments)
nest <- nest_legacy
unnest <- unnest_legacy
#library(RcppRoll) # rolling averages from vodonos? Likey not needed
library(purrr) # for iterative processing.
library(gridExtra) # for grid.arrange
```

```
## 
## Attaching package: 'gridExtra'
```

```
## The following object is masked from 'package:dplyr':
## 
##     combine
```


## Intro

Previous projections give the difference in projected mortality from average mortality at 15.6 C during the baseline period. Since the historical average temperature is not the same for all cities during the baseline period, the actual average baseline mortality in a city may differ considerably from that at 15.6 C.
 
 

###

```r
source(here::here("/code/functions/01_cluster_load_cp.r"))# load cluster functions
rm("cluster_load_cp"); rm("cluster_load_mv") # remove extra functions used for meta analysis 

source(here::here("code/functions/02_get_tmean.R"))
source(here::here("code/functions/03_lag_calc.R")) # Function to calculate lagged (5-dy moving average)
source(here::here("code/functions/04_join_doy_proj.R")) # Function to join to cluster fits, bounds, and other parameters to day of year mortality
source(here::here("code/functions/05_bound_tmean.R")) # Function to truncate tmean distribution at bounds.
###Functions for by-city calculations within a cluster
source(here::here("code/functions/06_rr_calc.R")) # Function for relative risk calculation
#dlnm::crosspred produces just predictions for the range of the input basis. It does not produce predictions for each row. Therefore, must reproduce with onebasis and relative risk calculation.
source(here::here("code/functions/07_project_spline.R")) # Function to loop through the projected temperatures, apply cluster coefficients, and calculate relative risk (no CI yet due to processing speed).
source(here::here("code/functions/08_sum_result_funs.R"))
```
  
### Linkages load
First load the county and city linkages, and the population values.

```r
options("object.size" = 2000000000000) # for bigger data limit
# nca_county_LUT <- fread(here("data/cira3/nca_county_LUT.csv"))
# nca_county_LUT <- nca_county_LUT %>% mutate(`FIPS_text` = FIPS)

mort_city_county_LUT <- read_xlsx(here("data/city_county_LUT.xlsx"))

head(mort_city_county_LUT)
```

<div data-pagedtable="false">
  <script data-pagedtable-source type="application/json">
{"columns":[{"label":["City"],"name":[1],"type":["chr"],"align":["left"]},{"label":["CITYNAME"],"name":[2],"type":["chr"],"align":["left"]},{"label":["STATENAM"],"name":[3],"type":["chr"],"align":["left"]},{"label":["COUNTY"],"name":[4],"type":["chr"],"align":["left"]},{"label":["fips_sm"],"name":[5],"type":["dbl"],"align":["right"]},{"label":["FIPS-text"],"name":[6],"type":["chr"],"align":["left"]},{"label":["length"],"name":[7],"type":["dbl"],"align":["right"]},{"label":["Cluster"],"name":[8],"type":["dbl"],"align":["right"]}],"data":[{"1":"akron","2":"Akron","3":"Ohio","4":"Summit","5":"39153","6":"39153","7":"5","8":"2"},{"1":"albany","2":"Albany","3":"New York","4":"Albany","5":"36001","6":"36001","7":"5","8":"2"},{"1":"albuq","2":"Albuquerque","3":"New Mexico","4":"Bernalillo","5":"35001","6":"35001","7":"5","8":"9"},{"1":"allent","2":"Allentown","3":"Pennsylvania","4":"Lehigh","5":"42077","6":"42077","7":"5","8":"1"},{"1":"allent","2":"Allentown","3":"Pennsylvania","4":"Northampton","5":"42095","6":"42095","7":"5","8":"1"},{"1":"anaheim","2":"Anaheim","3":"California","4":"Orange","5":"6059","6":"06059","7":"4","8":"5"}],"options":{"columns":{"min":{},"max":[10]},"rows":{"min":[10],"max":[10]},"pages":{}}}
  </script>
</div>

```r
mort_city_county_LUT <- mort_city_county_LUT %>% mutate(`FIPS_text` = paste("'", `FIPS-text`, "'", sep = ""))

cluster_LUT <-  mort_city_county_LUT%>%
  mutate (CITYNAME = casefold(CITYNAME)) %>% 
  select (Cluster,  City, CITYNAME, STATENAM , FIPS_txt = `FIPS-text`) #VALUE, COUNT, FIPS_txt = `FIPS-text`, fips_sm, FIPS,
```
 


Use the city-county-LUT to get the correct city/county values for the climate files Ron made in 2016. Those files are present on the J drive on ACE3, but require additional documentation for use. They need a description of the code used to produce them and the aggregation method. The climate model output aggregated for degrees celsius above baseline is available [here on ACE3](J:\projects\CIRA4_Labor\CIRA4_LOCA_Data).


```r
pop2010 <- read_xls(here::here("data/City-County-Cluster-2014-06-24_POP2010.xls"), "CitySum")
pop2010 <- pop2010 %>%
  mutate (CITYNAME = casefold(CITYNAME)) %>% 
  select (CITYNAME , n_counties = FREQUENCY, pop2010 = SUM_USA_Counties.POP2010)

cluster_LUT <- cluster_LUT %>%  
  inner_join(pop2010)  
```

```
## Joining, by = "CITYNAME"
```

### Load the mortality averages from the original city data (Schwartaz/vodonos)
For first projections, use observed deaths from death certificate (sum of counties included in Schwartz city boundary). These are directly tied to total populations of the counties included. Use the sum of populations from counties included in Schwartz city delimitation as basis for RR to actual deaths conversion. Later, apply the base RR and attributable RR to the overall population for cost calculations.
 

```r
dow <- read_csv(here::here("output/vodonos_out/historical.deaths/mean.deaths.dow.csv")) # Day of week mortality average for last period
```

```
## Parsed with column specification:
## cols(
##   dow = col_double(),
##   dow.names = col_character(),
##   CITYNAME = col_character(),
##   tot.mean = col_double()
## )
```

```r
glimpse (dow)
```

```
## Observations: 1,456
## Variables: 4
## $ dow       <dbl> 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,…
## $ dow.names <chr> "Sunday", "Sunday", "Sunday", "Sunday", "Sunday", "Sunday",…
## $ CITYNAME  <chr> "akron", "albany", "albuquerque", "allentown", "anaheim", "…
## $ tot.mean  <dbl> 13.7, 6.7, 11.0, 12.4, 42.7, 10.6, 4.9, 42.9, 6.1, 1.9, 4.6…
```

```r
doy <- read_csv(here::here("output/vodonos_out/historical.deaths/mean.deaths.doy.csv")) # Day of year mortality average for last period
```

```
## Parsed with column specification:
## cols(
##   doy = col_double(),
##   CITYNAME = col_character(),
##   tot.mean = col_double()
## )
```

```r
glimpse (doy)
```

```
## Observations: 76,128
## Variables: 3
## $ doy      <dbl> 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, …
## $ CITYNAME <chr> "akron", "albany", "albuquerque", "allentown", "anaheim", "a…
## $ tot.mean <dbl> 15.0, 6.7, 12.6, 13.8, 48.5, 12.6, 5.1, 52.2, 6.4, 2.1, 5.6,…
```

```r
#County mean tmean (weighted by number of grid points included in each county) was used for temperature relationship. Do the same going forward
tmean_fips <- read_xlsx(here::here("output/vodonos_out/Results-5-28-19.xlsx"), "data.matrix")
tmean_fips <- tmean_fips %>%  
  select(CITYNAME, citycode) %>% 
  mutate (FIPS_txt = stringr::str_pad(as.character (citycode), 5, "left", "0"),
          # Due to county selection within cities, some towns have no value in the original city-cluster-LUT table.
          # This is only a problem for Youngstown, OH, which has no matching fips code. Due to an error in the data.matrix lut from Schwartz
          FIPS_txt = gsub("39029", "39099", FIPS_txt)) # replace Schwartz data matrix for youngstown with a youngstown FIPS

tmean_fips   %>%   anti_join(cluster_LUT , by = "FIPS_txt")
```

<div data-pagedtable="false">
  <script data-pagedtable-source type="application/json">
{"columns":[{"label":["CITYNAME"],"name":[1],"type":["chr"],"align":["left"]},{"label":["citycode"],"name":[2],"type":["dbl"],"align":["right"]},{"label":["FIPS_txt"],"name":[3],"type":["chr"],"align":["left"]}],"data":[],"options":{"columns":{"min":{},"max":[10]},"rows":{"min":[10],"max":[10]},"pages":{}}}
  </script>
</div>

```r
doy<- doy %>% left_join(tmean_fips) %>% 
  mutate (CITYNAME = gsub("santabarbara", "santa barbara", CITYNAME)) %>% 
  left_join(cluster_LUT[, c("Cluster", "FIPS_txt", "pop2010")], by = "FIPS_txt") %>%
  select (cluster = Cluster, FIPS_txt, CITYNAME, doy, pop2010, total_mort = tot.mean)   
```

```
## Joining, by = "CITYNAME"
```

```r
 # 
# Providence is present in tmax trimmed file, but not in doy. Santa Barbara is just missing a space. 
# Update santa barbara in doy during processing.
```
 
 



 
### Pull in and stack all clusters (1-9)

```r
cluster_fits <-   cluster_load (4, 
          nsim = 1000, 
          out_folder = "output/vodonos_out/2019-06-13_mvcl_4_time/", 
          time_periods = c(3,4)
          )  
```

```
## [1] 4
```

```r
cluster_fits %>%  glimpse()
```

```
## Observations: 2
## Variables: 8
## $ cluster     <dbl> 4, 4
## $ time_period <dbl> 3, 4
## $ cp_fname    <chr> "/home/ad.abt.local/layc/cira3-mortality-home/output/vodo…
## $ cp_out      <list> [[<-10.2, -10.1, -10.0, -9.9, -9.8, -9.7, -9.6, -9.5, -9…
## $ mv_fname    <chr> "/home/ad.abt.local/layc/cira3-mortality-home/output/vodo…
## $ mv_out      <list> [[[<matrix[4 x 4]>, <matrix[4 x 4]>, <matrix[4 x 4]>, <m…
## $ daily_arg   <list> [[<-10.2, 31.9>, <10.36518, 23.51540>, <-0.059488302, -0…
## $ ma15_arg    <list> [[<-6.3, 30.9>, <10.36518, 23.51540>, <-0.06712759, -0.1…
```

```r
cluster_fits_tst<- cluster_fits %>% select(cluster, time_period, cp_out) %>% group_by(cluster)  %>% 
  pivot_wider(names_from = time_period, values_from = cp_out, names_prefix = "cp_out")
```
 
### Join to day of year deaths
The previously processed data can be joined on city name

```r
cluster_fits_doy <-  doy %>% 
  group_by(cluster,  FIPS_txt, CITYNAME) %>% 
  nest(.key = "doy_av_mort")  %>% 
  left_join(cluster_fits_tst) 
```

```
## Joining, by = "cluster"
```

```r
cluster_fits_doy %>%  glimpse()
```

```
## Observations: 208
## Variables: 6
## $ cluster     <dbl> 2, 2, 9, 1, 5, 1, 2, 4, 1, 9, 4, 6, 8, 1, 2, 1, 2, 6, 1, …
## $ FIPS_txt    <chr> "39153", "36001", "35001", "42077", "06059", "51059", "26…
## $ CITYNAME    <chr> "akron", "albany", "albuquerque", "allentown", "anaheim",…
## $ doy_av_mort <list> [<tbl_df[366 x 3]>, <tbl_df[366 x 3]>, <tbl_df[366 x 3]>…
## $ cp_out3     <list> [NULL, NULL, NULL, NULL, NULL, NULL, NULL, [<-10.2, -10.…
## $ cp_out4     <list> [NULL, NULL, NULL, NULL, NULL, NULL, NULL, [<-6.9, -6.8,…
```

 


### For 1973 to 2013
Read in livneh tmin/tmax, select CITYNAME == "Durham", average, 

```r
liv_4 <- read_xlsx( here::here("data/Trim_Livneh_Baseline/Compare_cluster_4.xlsx"))
liv_4 %>% head()
```

<div data-pagedtable="false">
  <script data-pagedtable-source type="application/json">
{"columns":[{"label":["CITYNAME"],"name":[1],"type":["chr"],"align":["left"]},{"label":["Cluster"],"name":[2],"type":["dbl"],"align":["right"]},{"label":["Year"],"name":[3],"type":["dbl"],"align":["right"]},{"label":["Month"],"name":[4],"type":["dbl"],"align":["right"]},{"label":["Day"],"name":[5],"type":["dbl"],"align":["right"]},{"label":["MEAN_livneh_TmaxC"],"name":[6],"type":["dbl"],"align":["right"]}],"data":[{"1":"Atlanta","2":"4","3":"1973","4":"5","5":"1","6":"25.57243"},{"1":"Atlanta","2":"4","3":"1973","4":"5","5":"10","6":"27.20626"},{"1":"Atlanta","2":"4","3":"1973","4":"5","5":"11","6":"29.70028"},{"1":"Atlanta","2":"4","3":"1973","4":"5","5":"12","6":"28.21888"},{"1":"Atlanta","2":"4","3":"1973","4":"5","5":"13","6":"23.87682"},{"1":"Atlanta","2":"4","3":"1973","4":"5","5":"14","6":"22.81589"}],"options":{"columns":{"min":{},"max":[10]},"rows":{"min":[10],"max":[10]},"pages":{}}}
  </script>
</div>

```r
cities_4 <- liv_4 %>% pull(CITYNAME) %>% unique() 
rm(liv_4)

get_tmean_livneh <- function(year = 1973, month, cities = cities_4  ){ # year = 1973
  liv_tmin <- read_csv(paste0("/media/jdrive/projects/COOLIT13_RiskComm/Trim_Livneh_Baseline/cityweights/livneh_NAmerExt_15Oct2014_", year, month, "tmin_mean.csv"))
  liv_tmax <- read_csv(paste0("/media/jdrive/projects/COOLIT13_RiskComm/Trim_Livneh_Baseline/cityweights/livneh_NAmerExt_15Oct2014_", year, month,  "_mean.csv"))
  if(cities[1] != "all"){ liv_tmin <- liv_tmin %>% 
    filter(CITYNAME %in% cities) }
  
   tmean_dt_yr <-  liv_tmin %>% 
    left_join(liv_tmax)  %>% 
     rename(date = livneh_date)%>%
    mutate(city = CITYNAME,
          CITYNAME = casefold(CITYNAME),
          gcm = "Livneh", 
           rcp = "baseline",
           dt_yr = 2000,
           year = lubridate::year(mdy_hms(date)) ,
           month = lubridate::month(mdy_hms(date)) ,
           doy = lubridate::yday(mdy_hms(date)),
           tmean0 = (MEAN_livneh_TminC + MEAN_livneh_TmaxC)/2)%>% 
    select(-OBJECTID , -MEAN_livneh_TminC, -MEAN_livneh_TmaxC)%>% 
      group_by(year, city, CITYNAME) %>% #gcm, rcp, dt_yr,
      nest(.key = "doy_tmean0")
  
  tmean_dt_yr
}
 
library(purrr)
ym <- expand.grid(year = 1993:2013,  month = sprintf("%02d", seq(1:12)))
liv_tmean <- map2_dfr(.x = ym$year, .y = ym$month, .f = get_tmean_livneh, cities = cities_4)  
```

### Get the relative risk values to adjust the baseline RR for each city to the city baseline mean temp
x intercepts (for tmean0 and tmean15) should be at the baseline average temperature for each city.


```r
city_mean <- liv_tmean %>%  
  mutate( doy_tmean0 = map( doy_tmean0, lag_calc )) %>%
  unnest() %>% ungroup() %>%
  group_by(city, CITYNAME)%>% 
  summarise(year =median(year),
            tmean0 = mean(tmean0),
            tmean15 = mean(tmean15))      
  # mutate(cluster = 4) %>%
  # inner_join(cluster_fits_tst )
city_mean<-  data.frame(city = "Intercept", CITYNAME = "intercept", year = 2003, tmean0=15.6, tmean15=15.6  )   %>%
  bind_rows(city_mean) %>%
  mutate(rr_tmean0_int_adj = calc_rr_avg (
          tmean_c =  tmean0,
         cluster_obj_list =list(pluck(cluster_fits_tst , "cp_out3",1) ,pluck(cluster_fits_tst , "cp_out4",1)),
          cp_name = "cp_0",
          knot_name = "knots_1"
        )   ,
        rr_tmean15_int_adj =  calc_rr_avg (
          tmean_c = tmean15,
          cluster_obj_list =list(pluck(cluster_fits_tst , "cp_out3",1) ,pluck(cluster_fits_tst , "cp_out4",1)),
          cp_name = "cp_05",
          knot_name = "knots_2"
        ),
        rr_total_int_adj = (rr_tmean0_int_adj + rr_tmean15_int_adj) )
```

```
## Warning in bind_rows_(x, .id): binding factor and character vector, coercing
## into character vector
```

```
## Warning in bind_rows_(x, .id): binding character and factor vector, coercing
## into character vector
```

```
## Warning in bind_rows_(x, .id): binding factor and character vector, coercing
## into character vector
```

```
## Warning in bind_rows_(x, .id): binding character and factor vector, coercing
## into character vector
```

```r
  #proj_spline for y4, proj_spline_av for y34
# highest city mean temp C is CharlestSC with 19.13
# 
city_mean %>% head()
```

<div data-pagedtable="false">
  <script data-pagedtable-source type="application/json">
{"columns":[{"label":[""],"name":["_rn_"],"type":[""],"align":["left"]},{"label":["city"],"name":[1],"type":["chr"],"align":["left"]},{"label":["CITYNAME"],"name":[2],"type":["chr"],"align":["left"]},{"label":["year"],"name":[3],"type":["dbl"],"align":["right"]},{"label":["tmean0"],"name":[4],"type":["dbl"],"align":["right"]},{"label":["tmean15"],"name":[5],"type":["dbl"],"align":["right"]},{"label":["rr_tmean0_int_adj"],"name":[6],"type":["dbl"],"align":["right"]},{"label":["rr_tmean15_int_adj"],"name":[7],"type":["dbl"],"align":["right"]},{"label":["rr_total_int_adj"],"name":[8],"type":["dbl"],"align":["right"]}],"data":[{"1":"Intercept","2":"intercept","3":"2003","4":"15.60000","5":"15.60000","6":"0.000000000","7":"0.000000000","8":"0.000000000","_rn_":"1"},{"1":"Atlanta","2":"atlanta","3":"2003","4":"16.34918","5":"16.35589","6":"0.002331646","7":"-0.004666255","8":"-0.002334609","_rn_":"2"},{"1":"Augusta","2":"augusta","3":"2003","4":"17.29993","5":"17.31023","6":"0.005251649","7":"-0.010592530","8":"-0.005340881","_rn_":"3"},{"1":"Birmingham","2":"birmingham","3":"2003","4":"16.95533","5":"16.95298","6":"0.004198095","7":"-0.008369589","8":"-0.004171495","_rn_":"4"},{"1":"CharlestSC","2":"charlestsc","3":"2003","4":"19.13006","5":"19.13935","6":"0.010763358","7":"-0.022056294","8":"-0.011292937","_rn_":"5"},{"1":"Charlotte","2":"charlotte","3":"2003","4":"16.02133","5":"16.02895","6":"0.001314768","7":"-0.002644959","8":"-0.001330191","_rn_":"6"}],"options":{"columns":{"min":{},"max":[10]},"rows":{"min":[10],"max":[10]},"pages":{}}}
  </script>
</div>

```r
# # For cluster 4 get overall mean temps
cl4_tmeans_y3_y4 <- city_mean %>% ungroup() %>% summarise(mean(tmean0), mean(tmean15))
```
 
 
  
## Run for all  dT


```r
# Define master function that is called for each degree change in each climate model and 11 year period.
dT_func <- function (gcm_sel ="CanESM2" ,
          dT_c_sel = 6,
          rcp_sel = "RCP85"  ,
          dt_yr_sel = 2091,  
          cluster_fits  = cluster_fits_doy ,
          cira_folder = "/media/jdrive/projects/COOLIT13_RiskComm/Mortality/Output/Trim/",#data size constraints; remove here::here("data/Trim/"),
          output_folder =   paste0("/media/jdrive/projects/CIRA4_Heat_Mortality/tables/Heat_Mortality_Output/", format(Sys.Date(), "%F"), "_y3y4_average_qa")
          ) {
  print (gcm_sel) ; print (dT_c_sel) ; print(rcp_sel); print(dt_yr_sel)
  # get data
  tic(msg = "get_tmean")
   tmean_daily <- get_tmean (cira_folder = cira_folder,
                          gcm = gcm_sel , rcp =  rcp_sel ,  dt_yr =  dt_yr_sel  )
   toc()

   # Lag calc   
tic(msg = "calculate lagged tmean")
tmean_daily <- tmean_daily %>% 
  mutate(dT_c = dT_c_sel ,
         doy_tmean = map( doy_tmean0, lag_calc )) %>% 
  select (-doy_tmean0)
toc()

#join to cluster fits, apply bounds, and other calculations
tic(msg = "join_doy_proj")
tmean_daily <- join_doy_proj_avg (tmean_daily = tmean_daily , cluster_param = cluster_fits_doy ) 
tmean_daily <- tmean_daily [tmean_daily$cluster == 4,]
toc()
 
tic(msg = "day_tm operation")
## add projected mortality and RR to tmean_daily  (trouble with list position means this may be more complicated than needed)
tmean_daily <-  tmean_daily %>% 
  mutate(
         day_tm3 =   pmap(list(day_tm,  cp_out3 ),
                             ~project_spline_rr_av( ..1, list(..2 ))),
         day_tm_4 = pmap(list(day_tm,   cp_out4  ),
                             ~project_spline_rr_av( ..1, list(..2 ))),
         day_tm_av = pmap(list(day_tm,  cp_out3  , cp_out4  ),
                             ~project_spline_rr_av( ..1, list(..2, ..3)))
    )
 
toc() 

return(tmean_daily)
}
```
 

```r
gcm_dt_lut <- read_xlsx(here("data/GCM_Period_dT_LUT.xlsx"), sheet = "GCM_Period_dT_LUT") 
gcm_dt_lut <- gcm_dt_lut %>% 
  rename (dt_year = model.period) %>% 
  mutate(min_dt_yr = dt_year - 5,
         max_dt_yr = dt_year + 5,
         )  
```

## Loa

# Iterate through all dT for each GCM.

```r
## Get GCM list for dt to run (minus baseline)
gcm_dt_lut_proj <- gcm_dt_lut %>%  
  filter(dT %in% c(1, 6))%>%  
  mutate (gcm = gsub("_", "-", gcm) )  %>% 
  filter (gcm != "baseline")  %>%  # remove as is stored elsewhere
  mutate (rcp = "RCP85")  

  output_folder_path <- paste0("/media/jdrive/projects/CIRA4_Heat_Mortality/tables/Heat_Mortality_Output/", format(Sys.Date(), "%F"), "_y3y4_avg_qa_rr_adj")
 if(!dir.exists(output_folder_path)) {dir.create(output_folder_path, recursive = TRUE)}
  
  compiled_city_mean_out <- pmap_dfr   (
    .l = list (
      gcm_dt_lut_proj$gcm   ,
      gcm_dt_lut_proj$dT   ,
      gcm_dt_lut_proj$rcp   ,
      gcm_dt_lut_proj$dt_year
    ),
    .f = dT_func,
    cluster_fits  = cluster_fits_doy[cluster_fits_doy$cluster == 4, ] ,
    cira_folder ="/media/jdrive/projects/COOLIT13_RiskComm/Mortality/Output/Trim/",
    output_folder =  output_folder_path
  )
```

```
## [1] "CanESM2"
## [1] 1
## [1] "RCP85"
## [1] 2011
## get_tmean: 8.49 sec elapsed
## calculate lagged tmean: 3.605 sec elapsed
## join_doy_proj: 1.203 sec elapsed
## day_tm operation: 19.772 sec elapsed
## [1] "CanESM2"
## [1] 6
## [1] "RCP85"
## [1] 2091
## get_tmean: 9.245 sec elapsed
## calculate lagged tmean: 3.795 sec elapsed
## join_doy_proj: 1.183 sec elapsed
## day_tm operation: 19.984 sec elapsed
## [1] "CCSM4"
## [1] 1
## [1] "RCP85"
## [1] 2011
## get_tmean: 7.54 sec elapsed
## calculate lagged tmean: 3.615 sec elapsed
## join_doy_proj: 0.787 sec elapsed
## day_tm operation: 19.25 sec elapsed
## [1] "GFDL-CM3"
## [1] 1
## [1] "RCP85"
## [1] 2013
## get_tmean: 7.73 sec elapsed
## calculate lagged tmean: 3.498 sec elapsed
## join_doy_proj: 1.025 sec elapsed
## day_tm operation: 19.577 sec elapsed
## [1] "GFDL-CM3"
## [1] 6
## [1] "RCP85"
## [1] 2087
## get_tmean: 9.053 sec elapsed
## calculate lagged tmean: 3.563 sec elapsed
## join_doy_proj: 0.746 sec elapsed
## day_tm operation: 19.882 sec elapsed
## [1] "GISS-E2-R"
## [1] 1
## [1] "RCP85"
## [1] 2026
## get_tmean: 7.541 sec elapsed
## calculate lagged tmean: 3.587 sec elapsed
## join_doy_proj: 0.989 sec elapsed
## day_tm operation: 19.567 sec elapsed
## [1] "HadGEM2-ES"
## [1] 1
## [1] "RCP85"
## [1] 2013
## get_tmean: 7.504 sec elapsed
## calculate lagged tmean: 3.544 sec elapsed
## join_doy_proj: 0.788 sec elapsed
## day_tm operation: 19.497 sec elapsed
## [1] "HadGEM2-ES"
## [1] 6
## [1] "RCP85"
## [1] 2077
## get_tmean: 9.17 sec elapsed
## calculate lagged tmean: 3.794 sec elapsed
## join_doy_proj: 0.85 sec elapsed
## day_tm operation: 20.532 sec elapsed
## [1] "MIROC5"
## [1] 1
## [1] "RCP85"
## [1] 2017
## get_tmean: 7.561 sec elapsed
## calculate lagged tmean: 3.764 sec elapsed
## join_doy_proj: 0.84 sec elapsed
## day_tm operation: 19.769 sec elapsed
```

```r
  # save(compiled_city_mean_out,
  #      file = file.path(output_folder_path, "compiled_city.Rdata"))
```



```r
city_mean <- city_mean %>% rename(base_year_cen = year, tmean0_mean = tmean0, tmean15_mean=tmean15)
dTc_compiled_gcm_city <- compiled_city_mean_out %>%  
  dplyr::select(cluster, city,  CITYNAME, FIPS_txt, dT_c, year, day_tm_av)  %>% 
  unnest() %>% 
  ungroup() %>% 
  inner_join(city_mean, by = c("city", "CITYNAME" )) %>% 
  select(cluster, city, CITYNAME, FIPS_txt, pop2010, total_mort, dT_c, year, date, gcm, rcp, dt_yr, doy, tmean0_mean,tmean15_mean, tmean0, tmean15, 
         rr_tmean0 ,rr_tmean0_int_adj,  an_tmean0 , 
         rr_tmean15,rr_tmean15_int_adj, an_tmean15,
         rr_total,   rr_total_int_adj, an_total)  %>%
  mutate(rr_tmean0_re_cent = rr_tmean0-rr_tmean0_int_adj,
         rr_tmean15_re_cent=  rr_tmean15-rr_tmean15_int_adj,
         rr_total_re_cent=  rr_total-rr_total_int_adj)
#rm(compiled_city_mean_out)

# dTc_compiled_gcm_city%>% write_excel_csv(path = file.path(output_folder_path, "compiled_city.csv"))
# rm(dTc_compiled_gcm_city)
```



```r
dTc_compiled_gcm_city %>%  filter(CITYNAME == "atlanta"& dT_c ==6) %>%  
  ggplot(aes(x= tmean0, y = rr_total ) ) + geom_point(color = "blueviolet") + 
  geom_point(aes(x= tmean0, y = rr_tmean0 ), color = "red") + 
  geom_point(aes(x= tmean0, y = rr_tmean15), color = "blue")+
  ylim(-.1,.1) 
```

![](QA_rr_x_center_files/figure-html/dt-compiled-gcm-city-av-plot-1.png)<!-- -->

```r
dTc_compiled_gcm_city %>%  filter(CITYNAME == "atlanta"& dT_c ==6) %>% 
  ggplot(aes(x= tmean0, y = rr_total_re_cent ) ) + geom_point(color = "blueviolet") + 
  geom_point(aes(x= tmean0, y = rr_tmean0_re_cent ), color= "red") + 
  geom_point(aes(x= tmean0, y = rr_tmean15_re_cent), color =  "blue")+
  ylim(-.1,.1)
```

![](QA_rr_x_center_files/figure-html/dt-compiled-gcm-city-av-plot-2.png)<!-- -->

```r
dTc_compiled_gcm_city %>% ungroup() %>% filter( rr_total == min(rr_total))
```

<div data-pagedtable="false">
  <script data-pagedtable-source type="application/json">
{"columns":[{"label":["cluster"],"name":[1],"type":["dbl"],"align":["right"]},{"label":["city"],"name":[2],"type":["chr"],"align":["left"]},{"label":["CITYNAME"],"name":[3],"type":["chr"],"align":["left"]},{"label":["FIPS_txt"],"name":[4],"type":["chr"],"align":["left"]},{"label":["pop2010"],"name":[5],"type":["dbl"],"align":["right"]},{"label":["total_mort"],"name":[6],"type":["dbl"],"align":["right"]},{"label":["dT_c"],"name":[7],"type":["dbl"],"align":["right"]},{"label":["year"],"name":[8],"type":["dbl"],"align":["right"]},{"label":["date"],"name":[9],"type":["chr"],"align":["left"]},{"label":["gcm"],"name":[10],"type":["chr"],"align":["left"]},{"label":["rcp"],"name":[11],"type":["chr"],"align":["left"]},{"label":["dt_yr"],"name":[12],"type":["dbl"],"align":["right"]},{"label":["doy"],"name":[13],"type":["dbl"],"align":["right"]},{"label":["tmean0_mean"],"name":[14],"type":["dbl"],"align":["right"]},{"label":["tmean15_mean"],"name":[15],"type":["dbl"],"align":["right"]},{"label":["tmean0"],"name":[16],"type":["dbl"],"align":["right"]},{"label":["tmean15"],"name":[17],"type":["dbl"],"align":["right"]},{"label":["rr_tmean0"],"name":[18],"type":["dbl"],"align":["right"]},{"label":["rr_tmean0_int_adj"],"name":[19],"type":["dbl"],"align":["right"]},{"label":["an_tmean0"],"name":[20],"type":["dbl"],"align":["right"]},{"label":["rr_tmean15"],"name":[21],"type":["dbl"],"align":["right"]},{"label":["rr_tmean15_int_adj"],"name":[22],"type":["dbl"],"align":["right"]},{"label":["an_tmean15"],"name":[23],"type":["dbl"],"align":["right"]},{"label":["rr_total"],"name":[24],"type":["dbl"],"align":["right"]},{"label":["rr_total_int_adj"],"name":[25],"type":["dbl"],"align":["right"]},{"label":["an_total"],"name":[26],"type":["dbl"],"align":["right"]},{"label":["rr_tmean0_re_cent"],"name":[27],"type":["dbl"],"align":["right"]},{"label":["rr_tmean15_re_cent"],"name":[28],"type":["dbl"],"align":["right"]},{"label":["rr_total_re_cent"],"name":[29],"type":["dbl"],"align":["right"]}],"data":[{"1":"4","2":"Oklahoma","3":"oklahoma","4":"40109","5":"718633","6":"13.5","7":"6","8":"2090","9":"2090-11-12","10":"GFDL-CM3","11":"RCP85","12":"2087","13":"316","14":"15.9251","15":"15.92103","16":"10.8318","17":"25.85375","18":"-0.0155637","19":"0.001015295","20":"-0.21011","21":"-0.06332139","22":"-0.001978773","23":"-0.8548388","24":"-0.0788851","25":"-0.0009634788","26":"-1.064949","27":"-0.016579","28":"-0.06134262","29":"-0.07792162"}],"options":{"columns":{"min":{},"max":[10]},"rows":{"min":[10],"max":[10]},"pages":{}}}
  </script>
</div>



```r
dTc_compiled_gcm_city %>%   filter(cluster == 4) %>%
  ggplot(aes(tmean0, tmean15, 
             color = (dT_c))) +  geom_point() 
```

![](QA_rr_x_center_files/figure-html/dt-compiled-gcm-city-av-plot-check-1.png)<!-- -->

```r
dTc_compiled_gcm_city  %>%   filter(cluster == 4) %>%   
  ggplot(aes(tmean0, tmean15, color = rr_total, shape = factor(dT_c))  ) +  
  geom_point()  +
  scale_colour_gradient2(low =  ("blue"), high =  ("red")) + #colours = terrain.colors(10)
  ggtitle("Cluster 4 projections for 1 and 6 dTC") +
  ylab("5-day moving average") +
  xlab("Daily C")
```

![](QA_rr_x_center_files/figure-html/dt-compiled-gcm-city-av-plot-check-2.png)<!-- -->

```r
dTc_compiled_gcm_city  %>%   filter(cluster == 4) %>%   
  ggplot(aes(tmean0, tmean15, color = rr_total_re_cent, shape = factor(dT_c)) ) +  
  geom_point()  +
  scale_colour_gradient2(low =  ("blue"), high =  ("red")) +
  ggtitle("Cluster 4 projections for 1 and 6 dTC (recentered for city mean temperature RR)") +
  ylab("5-day moving average") +
  xlab("Daily C")
```

![](QA_rr_x_center_files/figure-html/dt-compiled-gcm-city-av-plot-check-3.png)<!-- -->
 


```r
# estimate difference in mortality
#Rough based on weighted mean
chk_sum =  dTc_compiled_gcm_city %>%  filter(CITYNAME == "atlanta"& dT_c ==6  ) %>% ungroup() %>% group_by(year, gcm) %>%
  summarise(rr_total_mean = weighted.mean(rr_total, total_mort),  rr_total_re_cent_mean = weighted.mean(rr_total_re_cent, total_mort) , 
            tot_mort= sum(total_mort) , pop2010=mean(pop2010), total_an = (rr_total_mean * tot_mort) ,  total_re_cent_an =  (rr_total_re_cent_mean * tot_mort) ) 
chk_sum %>%   ungroup() %>% summarise_all("mean")
```

```
## Warning in mean.default(gcm): argument is not numeric or logical: returning NA
```

<div data-pagedtable="false">
  <script data-pagedtable-source type="application/json">
{"columns":[{"label":["year"],"name":[1],"type":["dbl"],"align":["right"]},{"label":["gcm"],"name":[2],"type":["dbl"],"align":["right"]},{"label":["rr_total_mean"],"name":[3],"type":["dbl"],"align":["right"]},{"label":["rr_total_re_cent_mean"],"name":[4],"type":["dbl"],"align":["right"]},{"label":["tot_mort"],"name":[5],"type":["dbl"],"align":["right"]},{"label":["pop2010"],"name":[6],"type":["dbl"],"align":["right"]},{"label":["total_an"],"name":[7],"type":["dbl"],"align":["right"]},{"label":["total_re_cent_an"],"name":[8],"type":["dbl"],"align":["right"]}],"data":[{"1":"2085","2":"NA","3":"-0.01275147","4":"-0.01041687","5":"15962.09","6":"3365297","7":"-203.5491","8":"-166.2839"}],"options":{"columns":{"min":{},"max":[10]},"rows":{"min":[10],"max":[10]},"pages":{}}}
  </script>
</div>

```r
# less rough based on function used for past calcs
mean_an_dt_city_doy <- dTc_compiled_gcm_city  %>%  filter(CITYNAME == "atlanta"& dT_c ==6) %>% 
  mutate(an_tmean0_bnd = rr_tmean0_re_cent * total_mort, an_tmean15_bnd = rr_tmean15_re_cent * total_mort)%>% 
  summarise_mean_an( an_vars = c(an_tmean0 = "an_tmean0", an_tmean15 ="an_tmean15", an_tmean0_bnd = "an_tmean0_bnd", an_tmean15_bnd ="an_tmean15_bnd") , 
                     cluster, city,  CITYNAME, FIPS_txt, dT_c, gcm, doy) %>% 
  rename(an_total_re_cent = mean_an_total_bnd) %>%   ungroup()  %>% 
  group_by(cluster, city,    CITYNAME, FIPS_txt,  dT_c, doy)   %>% 
  summarise_all("mean")
```

```
## Warning in mean.default(gcm): argument is not numeric or logical: returning NA
```

```
## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA

## Warning in mean.default(gcm): argument is not numeric or logical: returning NA
```

```r
mean_an_dt_city_doy  %>%   ungroup() %>% select (doy, mean_an_total , an_total_re_cent  )   %>% summarise_all("sum")
```

<div data-pagedtable="false">
  <script data-pagedtable-source type="application/json">
{"columns":[{"label":["doy"],"name":[1],"type":["dbl"],"align":["right"]},{"label":["mean_an_total"],"name":[2],"type":["dbl"],"align":["right"]},{"label":["an_total_re_cent"],"name":[3],"type":["dbl"],"align":["right"]}],"data":[{"1":"67161","2":"-202.8953","3":"-165.5579"}],"options":{"columns":{"min":{},"max":[10]},"rows":{"min":[10],"max":[10]},"pages":{}}}
  </script>
</div>

```r
mean_an_dt_city_doy %>% ggplot(aes(doy, mean_an_total, color = "Original deaths due to temp")) + 
  geom_point() +
  geom_point(aes(doy, an_total_re_cent, color = "Deaths due to recentered temperature" )) + 
  theme_classic() + 
  theme( legend.title =element_blank() ) + ylab("Mean change in deaths per day") + xlab ("Day of year")
```

![](QA_rr_x_center_files/figure-html/dt-compiled-gcm-city-sum-1.png)<!-- -->

   
 
## Session Info 

```r
if (!require("devtools", 
             character.only = TRUE)) { devtools::session_info()} else
             {sessionInfo()}
```

```
## Loading required package: devtools
```

```
## Loading required package: usethis
```

```
## R version 3.6.1 (2019-07-05)
## Platform: x86_64-pc-linux-gnu (64-bit)
## Running under: Red Hat Enterprise Linux Server 7.7 (Maipo)
## 
## Matrix products: default
## BLAS:   /opt/R/3.6.1/lib64/R/lib/libRblas.so
## LAPACK: /opt/R/3.6.1/lib64/R/lib/libRlapack.so
## 
## locale:
##  [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
##  [3] LC_TIME=en_US.UTF-8        LC_COLLATE=en_US.UTF-8    
##  [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
##  [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
##  [9] LC_ADDRESS=C               LC_TELEPHONE=C            
## [11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       
## 
## attached base packages:
## [1] splines   stats     graphics  grDevices utils     datasets  methods  
## [8] base     
## 
## other attached packages:
##  [1] devtools_2.2.1    usethis_1.5.1     gridExtra_2.3     lubridate_1.7.4  
##  [5] forcats_0.4.0     stringr_1.4.0     dplyr_0.8.3       purrr_0.3.3      
##  [9] tidyr_1.0.0       tibble_2.1.3      ggplot2_3.2.1     tidyverse_1.3.0  
## [13] data.table_1.12.6 here_0.1          mvmeta_0.4.11     tsModel_0.6      
## [17] dlnm_2.3.9        mgcv_1.8-31       nlme_3.1-142      MASS_7.3-51.4    
## [21] survival_3.1-7    readr_1.3.1       readxl_1.3.1      tictoc_1.0       
## 
## loaded via a namespace (and not attached):
##  [1] httr_1.4.1        pkgload_1.0.2     jsonlite_1.6      modelr_0.1.5     
##  [5] assertthat_0.2.1  cellranger_1.1.0  remotes_2.1.0     yaml_2.2.0       
##  [9] sessioninfo_1.1.1 pillar_1.4.3      backports_1.1.5   lattice_0.20-38  
## [13] glue_1.3.1        digest_0.6.23     rvest_0.3.5       colorspace_1.4-1 
## [17] htmltools_0.4.0   Matrix_1.2-17     pkgconfig_2.0.3   broom_0.5.2      
## [21] haven_2.2.0       scales_1.1.0      processx_3.4.1    generics_0.0.2   
## [25] farver_2.0.1      ellipsis_0.3.0    withr_2.1.2       lazyeval_0.2.2   
## [29] cli_2.0.0         magrittr_1.5      crayon_1.3.4      ps_1.3.0         
## [33] memoise_1.1.0     evaluate_0.14     fs_1.3.1          fansi_0.4.0      
## [37] xml2_1.2.2        pkgbuild_1.0.6    prettyunits_1.0.2 tools_3.6.1      
## [41] hms_0.5.2         lifecycle_0.1.0   munsell_0.5.0     reprex_0.3.0     
## [45] callr_3.3.2       compiler_3.6.1    rlang_0.4.2       grid_3.6.1       
## [49] rstudioapi_0.10   labeling_0.3      rmarkdown_1.18    testthat_2.3.0   
## [53] gtable_0.3.0      DBI_1.1.0         R6_2.4.1          knitr_1.26       
## [57] zeallot_0.1.0     utf8_1.1.4        rprojroot_1.3-2   desc_1.2.0       
## [61] stringi_1.4.3     Rcpp_1.0.3        vctrs_0.2.1       dbplyr_1.4.2     
## [65] tidyselect_0.2.5  xfun_0.11
```
 
 
  
